@@ -201,9 +201,8 @@ class Tinebase_Application
         
         if ($filter === null && $pagination === null) {
             try {
-                $result = Tinebase_Cache_PerRequest::getInstance()->load(__CLASS__, __METHOD__, 'allApplications', Tinebase_Cache_PerRequest::VISIBILITY_SHARED);
-                
-                return $result;
+                return Tinebase_Cache_PerRequest::getInstance()->load(__CLASS__, __METHOD__,
+                    'allApplications', Tinebase_Cache_PerRequest::VISIBILITY_SHARED);
             } catch (Tinebase_Exception_NotFound $tenf) {
                 // do nothing
             }
@@ -655,9 +654,10 @@ class Tinebase_Application
                 case 'rootnode':
                     $count = 0;
                     try {
-                        if (Tinebase_FileSystem::getInstance()->isDir($_application->name)) {
+                        $tries = 0;
+                        while (Tinebase_FileSystem::getInstance()->isDir($_application->name) && ++$tries < 10) {
                             // note: TFS expects name here, not ID
-                            $count = Tinebase_FileSystem::getInstance()->rmdir($_application->name, true);
+                            $count += (int)Tinebase_FileSystem::getInstance()->rmdir($_application->name, true);
                         }
                     } catch (Tinebase_Exception_NotFound $tenf) {
                         // nothing to do
@@ -665,7 +665,7 @@ class Tinebase_Application
                     } catch (Tinebase_Exception_Backend $teb) {
                         // nothing to do
                         Tinebase_Exception::log($teb);
-                    } catch (Exception $e) {
+                    } catch (Throwable $e) {
                         // problem!
                         Tinebase_Exception::log($e);
                     }
@@ -742,13 +742,15 @@ class Tinebase_Application
         }
 
         /** @var Tinebase_Model_Application $app */
-        foreach($apps as $app) {
+        foreach ($apps as $app) {
             /** @var Tinebase_Controller $controllerClass */
             $controllerClass = $app->name . '_Controller';
             if (!class_exists(($controllerClass))) {
                 try {
                     $controllerInstance = Tinebase_Core::getApplicationInstance($app->name, '', true);
-                } catch(Tinebase_Exception_NotFound $tenf) {
+                } catch (Tinebase_Exception_NotFound $tenf) {
+                    continue;
+                } catch (Tinebase_Exception_AccessDenied $tead) {
                     continue;
                 }
             } else {
