@@ -66,6 +66,9 @@ class Felamimail_Backend_Imap extends Zend_Mail_Storage_Imap
         $connectionOptions = Tinebase_Mail::getConnectionOptions(20);
         $this->_protocol->setConnectionOptions($connectionOptions);
 
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+            __METHOD__ . '::' . __LINE__ . ' Connection options: ' . print_r($connectionOptions, true));
+
         if ($this->_logImapRequestsAndResponses && Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) {
             $this->_protocol->setLogger(Tinebase_Core::getLogger());
         }
@@ -89,6 +92,9 @@ class Felamimail_Backend_Imap extends Zend_Mail_Storage_Imap
         $selectParams = $capabilities && in_array('CONDSTORE', $capabilities['capabilities']) ? ['(CONDSTORE)'] : [];
 
         try {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                __METHOD__ . '::' . __LINE__ . ' Selecting folder ' . $folderToSelect);
+
             $this->selectFolder($folderToSelect, $selectParams);
         } catch (Zend_Mail_Storage_Exception $zmse) {
             throw new Felamimail_Exception_IMAPFolderNotFound('Could not select ' . $folderToSelect . '(' . $zmse->getMessage() . ')');
@@ -1097,7 +1103,8 @@ class Felamimail_Backend_Imap extends Zend_Mail_Storage_Imap
             }
 
             // remove other bad chars to prevent "iconv_mime_decode_headers(): Detected an illegal character in input string"
-            $result = iconv('UTF-8', 'ASCII//TRANSLIT', $result);
+            // TODO catch exceptions here? this still sometimes throws ErrorException "iconv(): Detected an illegal character in input string"
+            $result = @iconv('UTF-8', 'ASCII//TRANSLIT', $result);
         }
         
         return $result;
