@@ -102,6 +102,13 @@ class Tinebase_Controller extends Tinebase_Controller_Event
         // sanitize loginname - we might not support invalid/out of range characters
         $loginName = Tinebase_Core::filterInputForDatabase($loginName);
 
+        // rolechange user: username*authuser?
+        $authUserParts = preg_split('/\*+(?=[^*]+$)/', $loginName);
+        if (isset($authUserParts[1]) && Tinebase_User::getInstance()->getUserByLoginName($authUserParts[1])) {
+            $loginName = $authUserParts[1];
+            $roleChangeUserName = $authUserParts[0];
+        }
+
         $authResult = Tinebase_Auth::getInstance()->authenticate($loginName, $password);
 
         $accessLog = Tinebase_AccessLog::getInstance()->getAccessLogEntry($loginName, $authResult, $request,
@@ -126,6 +133,10 @@ class Tinebase_Controller extends Tinebase_Controller_Event
             Felamimail_Controller::getInstance()->handleAccountLogin($user, $password);
         }
 
+        if (isset($roleChangeUserName)) {
+            Tinebase_Controller::getInstance()->changeUserAccount($roleChangeUserName);
+        }
+
         return true;
     }
 
@@ -597,13 +608,19 @@ class Tinebase_Controller extends Tinebase_Controller_Event
             && in_array($loginName, $allowedRoleChangesArray[$currentAccountName])
         ) {
             $user = Tinebase_User::getInstance()->getFullUserByLoginName($loginName);
-            Tinebase_Session::getSessionNamespace()->userAccountChanged = true;
-            Tinebase_Session::getSessionNamespace()->originalAccountName = $currentAccountName;
-            
+            // CalDAV / ActiveSync have no session
+            Tinebase_Core::set('userAccountChanged', true);
+            Tinebase_Core::set('originalAccountName', $currentAccountName);
+            if (Tinebase_Session::isStarted()) {
+                Tinebase_Session::getSessionNamespace()->userAccountChanged = true;
+                Tinebase_Session::getSessionNamespace()->originalAccountName = $currentAccountName;
+            }
         } else if (Tinebase_Session::getSessionNamespace()->userAccountChanged 
             && isset($allowedRoleChangesArray[Tinebase_Session::getSessionNamespace()->originalAccountName])
         ) {
             $user = Tinebase_User::getInstance()->getFullUserByLoginName(Tinebase_Session::getSessionNamespace()->originalAccountName);
+            Tinebase_Core::set('userAccountChanged', false);
+            Tinebase_Core::set('originalAccountName', null);
             Tinebase_Session::getSessionNamespace()->userAccountChanged = false;
             Tinebase_Session::getSessionNamespace()->originalAccountName = null;
         }
@@ -915,13 +932,12 @@ class Tinebase_Controller extends Tinebase_Controller_Event
 
         try {
             $session = Tinebase_Session::getSessionNamespace();
-        } catch (Zend_Session_Exception $zse) {
-            $session = null;
-        }
-        
-        return ($session instanceof Zend_Session_Namespace && isset($session->userAccountChanged)) 
+            return ($session instanceof Zend_Session_Namespace && isset($session->userAccountChanged))
                 ? $session->userAccountChanged
                 : false;
+        } catch (Zend_Session_Exception $zse) {
+            return !! Tinebase_Core::get('userAccountChanged');
+        }
     }
 
     /**
@@ -1044,6 +1060,13 @@ class Tinebase_Controller extends Tinebase_Controller_Event
             ]))->toArray());
         });
 
+        $r->addGroup('', function (\FastRoute\RouteCollector $routeCollector) {
+            $routeCollector->get('/health', (new Tinebase_Expressive_RouteHandler(
+                Tinebase_Controller::class, 'healthCheck', [
+                Tinebase_Expressive_RouteHandler::IS_PUBLIC => true
+            ]))->toArray());
+        });
+
         $r->addGroup('/Tinebase', function (\FastRoute\RouteCollector $routeCollector) {
             $routeCollector->get('/_status[/{apiKey}]', (new Tinebase_Expressive_RouteHandler(
                 Tinebase_Controller::class, 'getStatus', [
@@ -1069,6 +1092,8 @@ class Tinebase_Controller extends Tinebase_Controller_Event
     /**
      * @return \Zend\Diactoros\Response
      * @throws Tinebase_Exception_AccessDenied
+     *
+     * @todo replace with "healthCheck"?
      */
     public function getStatus($apiKey = null)
     {
@@ -1089,6 +1114,104 @@ class Tinebase_Controller extends Tinebase_Controller_Event
         return $response;
     }
 
+    /**
+     * return tine20 health (json encoded)
+     * - status can be one of [pass, fail, warn]
+     * - returns http error code 500 on fail
+     * - checks: config, db, temp dir, files dir
+     * - client ip address needs to be in Tinebase_Config::ALLOWEDHEALTHCHECKIPS
+     *
+     * @return \Zend\Diactoros\Response
+     *
+     * @todo add cache check (see \Tinebase_Frontend_Cli::monitoringCheckCache + add $this->checkCache())
+     * @todo use api key instead of client whitelist?
+     */
+    public function healthCheck()
+    {
+        $clientIp = Tinebase_Core::getRequest()->getRemoteAddress();
+        if (! in_array($clientIp, Tinebase_Config::getInstance()->{Tinebase_Config::ALLOWEDHEALTHCHECKIPS})) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE))
+                Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' client ip not allowed: '
+                    . $clientIp);
+            return new \Zend\Diactoros\Response('php://memory', 404);
+        }
+
+        $status = 'pass';
+        $problems = [];
+        if (! Tinebase_Controller::getInstance()->checkConfig()) {
+            $status = 'fail';
+            $problems[] = 'config';
+        }
+
+        try {
+            Tinebase_Core::getDb();
+        } catch (Zend_Db_Adapter_Exception $zdae) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::ERR))
+                Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' '
+                    . $zdae->getMessage());
+            $status = 'fail';
+            $problems[] = 'database';
+        }
+
+        $dirsToCheck = [
+            'temp dir' => Tinebase_Core::getTempDir(),
+            'files dir' => Tinebase_Core::getConfig()->filesdir
+        ];
+        foreach ($dirsToCheck as $key => $dir) {
+            if (empty($dir)) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::ERR))
+                    Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' ' . $key . ' not configured');
+                $status = 'fail';
+                $problems[] = $key;
+            } else {
+                $filename = $dir . DIRECTORY_SEPARATOR . __METHOD__ . Tinebase_Record_Abstract::generateUID(10);
+                try {
+                    file_put_contents($filename, 'abc');
+                    unlink($filename);
+                } catch (Throwable $t) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::ERR))
+                        Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' ' . $t->getMessage());
+                    $status = 'fail';
+                    $problems[] = $key;
+                }
+            }
+        }
+
+        $code = $status === 'fail' ? 500 : 200;
+        $data = [
+            'status' => $status,
+            'problems' => $problems,
+        ];
+        return new \Zend\Diactoros\Response\JsonResponse($data, $code);
+    }
+
+    /**
+     * @return bool
+     */
+    public function checkConfig()
+    {
+        $configfile = Setup_Core::getConfigFilePath();
+        if ($configfile) {
+            $configfile = escapeshellcmd($configfile);
+            if (preg_match('/^win/i', PHP_OS)) {
+                exec("php -l $configfile 2> NUL", $error, $code);
+            } else {
+                exec("php -l $configfile 2> /dev/null", $error, $code);
+            }
+            if ($code == 0) {
+                return true;
+            } else {
+                if (Tinebase_Core::isLogLevel(Zend_Log::CRIT))
+                    Tinebase_Core::getLogger()->crit(__METHOD__ . '::' . __LINE__ . ' Config file syntax error');
+            }
+        } else {
+            if (Tinebase_Core::isLogLevel(Zend_Log::CRIT))
+                Tinebase_Core::getLogger()->crit(__METHOD__ . '::' . __LINE__ . ' Config file missing');
+        }
+
+        return false;
+    }
+
     /**
      * @param int|string $size
      * @param string $ext
@@ -1162,6 +1285,115 @@ class Tinebase_Controller extends Tinebase_Controller_Event
             ->withAddedHeader('Content-Type', $mime);
     }
 
+    /**
+     * @return bool
+     */
+    public function actionQueueConsistencyCheck()
+    {
+        if (Tinebase_Config::getInstance()->{Tinebase_Config::ACTIONQUEUE}->{Tinebase_Config::ACTIONQUEUE_ACTIVE} &&
+            Tinebase_ActionQueue::getInstance()->hasAsyncBackend()) {
+
+            if (null === ($queueState = json_decode(Tinebase_Application::getInstance()->getApplicationState('Tinebase',
+                    Tinebase_Application::STATE_ACTION_QUEUE_STATE), true))) {
+                $queueState = [
+                    'lastFullCheck' => 0,
+                    'lastSizeOver10k' => false,
+                    'actionQueueMissingQueueKeys' => [],
+                    'actionQueueMissingDaemonKeys' => [],
+                    'lastLRSizeOver10k' => false,
+                    'actionQueueLRMissingQueueKeys' => [],
+                    'actionQueueLRMissingDaemonKeys' => [],
+                ];
+            }
+
+            $time = [
+                'actionQueue' => ['dataWarn' => 15, 'dataErr' => 60],
+                'actionQueueLR' => ['dataWarn' => 60, 'dataErr' => 5 * 60],
+            ];
+
+            foreach (['actionQueue' => Tinebase_ActionQueue::getInstance(), 'actionQueueLR' => Tinebase_ActionQueueLongRun::getInstance()] as $qName => $actionQueue) {
+
+                $missingQueueKeys = [];
+                $missingDaemonKeys = [];
+                $warn = null;
+                $err = null;
+                // go through queue and daemon struct and check timestamps in data
+                // remember stuff we did not find
+                foreach ($actionQueue->getQueueKeys() as $key) {
+                    if (empty($data = $actionQueue->getData($key))) {
+                        if (isset($queueState[$qName . 'MissingQueueKeys'][$key])) {
+                            if (null === $warn) {
+                                $warn = $qName . ' contains keys which are not present in data';
+                            }
+                        } else {
+                            $missingQueueKeys[$key] = true;
+                        }
+                    } else {
+                        if (($timediff = time() - $data['time']) > $time[$qName]['dataWarn'] * 60) {
+                            if (null === $warn) {
+                                $warn = $qName . ' data contains data older than ' . $time[$qName]['dataWarn'] . ' minutes';
+                            }
+                        }
+                        if ($timediff > $time[$qName]['dataErr'] * 60) {
+                            $err = $qName . ' data contains data older than ' . $time[$qName]['dataErr'] . ' minutes';
+                        }
+                    }
+                }
+                $queueState[$qName . 'MissingQueueKeys'] = $missingQueueKeys;
+
+                foreach ($actionQueue->getDaemonStructKeys() as $key) {
+                    if (empty($data = $actionQueue->getData($key))) {
+                        if (isset($queueState[$qName . 'MissingDaemonKeys'][$key])) {
+                            if (null === $warn) {
+                                $warn = $qName . ' daemon contains keys which are not present in data';
+                            }
+                        } else {
+                            $missingDaemonKeys[$key] = true;
+                        }
+                    } else {
+                        if (($timediff = time() - $data['time']) > $time[$qName]['dataWarn'] * 60) {
+                            if (null === $warn) {
+                                $warn = $qName . ' data contains data older than ' . $time[$qName]['dataWarn'] . ' minutes';
+                            }
+                        }
+                        if ($timediff > $time[$qName]['dataErr'] * 60) {
+                            $err = $qName . ' data contains data older than ' . $time[$qName]['dataErr'] . ' minutes';
+                        }
+                    }
+                }
+                $queueState[$qName . 'MissingDaemonKeys'] = $missingDaemonKeys;
+
+                // go through data keys and check timestmaps
+                while (false !== ($data = $actionQueue->iterateAllData())) {
+                    foreach ($data as $jobId) {
+                        if (!empty($job = $actionQueue->getData($jobId))) {
+                            if (($timediff = time() - $job['time']) > $time[$qName]['dataWarn'] * 60) {
+                                if (null === $warn) {
+                                    $warn = $qName . ' data contains data older than ' . $time[$qName]['dataWarn'] . ' minutes';
+                                }
+                            }
+                            if ($timediff > $time[$qName]['dataErr'] * 60) {
+                                $err = $qName . ' data contains data older than ' . $time[$qName]['dataErr'] . ' minutes';
+                            }
+                        }
+                    }
+                }
+
+                if (null !== $err) {
+                    $e = Tinebase_Exception($err);
+                    Tinebase_Exception::log($e);
+                } elseif (null !== $warn) {
+                    ($e = Tinebase_Exception($warn))->setLogLevelMethod('warn');
+                    Tinebase_Exception::log($e);
+                }
+            }
+
+            Tinebase_Application::getInstance()->setApplicationState('Tinebase',
+                Tinebase_Application::STATE_ACTION_QUEUE_STATE, json_encode($queueState));
+        }
+        return true;
+    }
+
     /**
      * @return bool
      */
