@@ -278,7 +278,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             throw new Felamimail_Exception_PasswordMissing($translation->_('shared / adb_list accounts need to have a password set'));
         }
         if (! $_record->email) {
-            throw new Tinebase_Exception_UnexpectedValue($translation->_('shared / adb_list accounts need to have an email set'));
+            throw new Tinebase_Exception_SystemGeneric($translation->_('shared / adb_list accounts need to have an email set'));
         }
 
         $this->_createSharedEmailUser($_record);
@@ -655,6 +655,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             $_oldRecord,
             $_throw,
             [
+                Felamimail_Model_Account::TYPE_SYSTEM,
                 Felamimail_Model_Account::TYPE_SHARED,
             ],
             Felamimail_Model_Account::TYPE_USER_INTERNAL
@@ -669,13 +670,19 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
      * @param $_to
      * @return bool
      * @throws Tinebase_Exception_SystemGeneric
+     * @throws Tinebase_Exception_UnexpectedValue
      */
     protected function _doConvertTo($_record, $_oldRecord, $_throw, $_from, $_to)
     {
         $result = ($_record->type === $_to && in_array($_oldRecord->type, $_from));
 
         if ($_throw && $_record->type !== $_oldRecord->type && ! $result) {
-            throw new Tinebase_Exception_UnexpectedValue('type can not change');
+            $translate = Tinebase_Translation::getTranslation('Felamimail');
+            throw new Tinebase_Exception_SystemGeneric(str_replace(
+                ['{0}', '{1}'],
+                [$_oldRecord->type, $_record->type],
+                $translate->_('Account type cannot be changed from {0} to {1}')
+            ));
         }
 
         if ($result) {
@@ -708,6 +715,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         $this->_transferEmailUserIdXprops($_record, $_oldRecord);
 
         if (! isset($_record->xprops()[Felamimail_Model_Account::XPROP_EMAIL_USERID_IMAP])) {
+            $translate = Tinebase_Translation::getTranslation('Felamimail');
             throw new Tinebase_Exception_SystemGeneric($translate->_('Could not find email user xprops!'));
         }
 
@@ -740,8 +748,8 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         if (isset($_oldRecord->xprops()[Felamimail_Model_Account::XPROP_EMAIL_USERID_IMAP])) {
             Tinebase_EmailUser_XpropsFacade::setXprops($_record,
                 $_oldRecord->xprops()[Tinebase_Model_FullUser::XPROP_EMAIL_USERID_IMAP], false);
-        } else if ($_record->user_id) {
-            $user = Tinebase_User::getInstance()->getFullUserById($_record->user_id);
+        } else if ($_oldRecord->user_id) {
+            $user = Tinebase_User::getInstance()->getFullUserById($_oldRecord->user_id);
             Tinebase_EmailUser_XpropsFacade::setXprops($_record,
                 $user->xprops()[Tinebase_Model_FullUser::XPROP_EMAIL_USERID_IMAP], false);
         }
@@ -768,6 +776,10 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         // copy password from system user account
         if ($_oldRecord->type !== Felamimail_Model_Account::TYPE_SYSTEM) {
             $systemEmailUser = $this->_getEmailSystemUser($_record->user_id);
+            if (! $systemEmailUser->getId()) {
+                $translation = Tinebase_Translation::getTranslation('Felamimail');
+                throw new Tinebase_Exception_UnexpectedValue($translation->_('System account of user is missing'));
+            }
             $emailUser = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($_record);
             $emailUserBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
             $emailUserBackend->copyPassword($systemEmailUser, $emailUser);
@@ -836,6 +848,14 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
     {
         if ($_record->type !== Felamimail_Model_Account::TYPE_USER_INTERNAL) {
             if ($_record->type === Felamimail_Model_Account::TYPE_USER) {
+                if ($_record->user_id !== $_oldRecord->user_id) {
+                    // owner is changed - only allow this in admin mode
+                    if ($this->doContainerACLChecks()) {
+                        throw new Tinebase_Exception_AccessDenied('owner change is not allowed');
+                    }
+                    $this->_setDefaultGrants($_record);
+                }
+
                 $this->_beforeUpdateStandardAccountCredentials($_record, $_oldRecord);
             } else {
                 $this->_beforeUpdateSharedAccountCredentials($_record, $_oldRecord);
@@ -1013,6 +1033,25 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
      */
     protected function _inspectAfterUpdate($updatedRecord, $record, $currentRecord)
     {
+        switch ($updatedRecord->type) {
+            case Felamimail_Model_Account::TYPE_SYSTEM:
+            case Felamimail_Model_Account::TYPE_SHARED:
+            case Felamimail_Model_Account::TYPE_USER_INTERNAL:
+                $this->_afterUpdateSetSieve($updatedRecord, $currentRecord);
+                break;
+        }
+    }
+
+    /**
+     * @param Felamimail_Model_Account $updatedRecord
+     * @param Felamimail_Model_Account $currentRecord
+     */
+    protected function _afterUpdateSetSieve($updatedRecord, $currentRecord)
+    {
+        if (empty($updatedRecord->sieve_hostname)) {
+            return;
+        }
+
         if ($updatedRecord->sieve_notification_email != $currentRecord->sieve_notification_email) {
             Felamimail_Controller_Sieve::getInstance()->setNotificationEmail($updatedRecord->getId(),
                 $updatedRecord->sieve_notification_email);
@@ -1026,7 +1065,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             Felamimail_Controller_Sieve::getInstance()->updateAutoMoveNotificationScript($updatedRecord);
         }
     }
-    
+
     /**
      * check if user has the right to manage accounts
      * 
@@ -1328,7 +1367,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         $imapBackend = $this->_getIMAPBackend($account);
         if ($imapBackend && $imapBackend->getFolderStatus(Felamimail_Model_Folder::encodeFolderName($folderName)) === false) {
             $systemFolder = $this->_createSystemFolder($account, $folderName);
-            if ($systemFolder->globalname !== $folderName) {
+            if ($systemFolder && $systemFolder->globalname !== $folderName) {
                 $account->{$systemFolderField} = $systemFolder->globalname;
                 $this->_backend->update($account);
             }
@@ -1385,7 +1424,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
      * 
      * @param Felamimail_Model_Account $_account
      * @param string $_systemFolder
-     * @return Felamimail_Model_Folder
+     * @return Felamimail_Model_Folder|null
      */
     protected function _createSystemFolder(Felamimail_Model_Account $_account, $_systemFolder)
     {
@@ -1401,6 +1440,11 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
                 . $feisu->getMessage());
             // try again with INBOX as parent because some IMAP servers can not handle namespaces correctly
             $result = Felamimail_Controller_Folder::getInstance()->create($_account, $splitFolderName['localname'], 'INBOX');
+        } catch (Tinebase_Exception_SystemGeneric $tesg) {
+            // folder already there ...
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' '
+                . $tesg->getMessage());
+            $result = null;
         }
         
         return $result;
@@ -1466,8 +1510,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         }
 
         if (null !== ($systemAccount = $this->getSystemAccount($_account->getId()))) {
-            Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
-                . ' system account "' . $systemAccount->name . '" already exists.');
+            // system account already exists
             return $systemAccount;
         }
 
@@ -1530,12 +1573,11 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         $systemAccount->user = $emailUser->getEmailUserName($_user);
         $systemAccount->password = $pwd;
 
-        if (Felamimail_Config::getInstance()
-            ->featureEnabled(Felamimail_Config::FEATURE_SYSTEM_ACCOUNT_AUTOCREATE_FOLDERS)) {
+        if ($pwd && $this->_doAutocreateFolders($pwd)) {
             $this->_autoCreateSystemAccountFolders($systemAccount);
         }
 
-        if (Felamimail_Config::getInstance()
+        if ($pwd && Felamimail_Config::getInstance()
             ->featureEnabled(Felamimail_Config::FEATURE_ACCOUNT_MOVE_NOTIFICATIONS)) {
             $this->_autoCreateMoveNotifications($systemAccount);
         }
@@ -1549,7 +1591,21 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
 
         return $systemAccount;
     }
-    
+
+    /**
+     * do we auto-create folders?
+     *
+     * @param $pwd
+     * @return bool
+     * @throws Setup_Exception
+     * @throws Tinebase_Exception_InvalidArgument
+     */
+    protected function _doAutocreateFolders($pwd)
+    {
+        return ! empty($pwd) && Felamimail_Config::getInstance()
+            ->featureEnabled(Felamimail_Config::FEATURE_SYSTEM_ACCOUNT_AUTOCREATE_FOLDERS);
+    }
+
     /**
      * add folder defaults
      * 
@@ -1625,7 +1681,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             Tinebase_Exception::log($e);
         }
     }
-    
+
     /**
      * returns email address used for the account by checking the user data and imap config
      * 
@@ -1984,7 +2040,6 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         ]));
         $this->doContainerACLChecks($checks);
 
-        $listBackend = new Addressbook_Backend_List();
         foreach ($sharedAccounts as $account) {
             $emailUserId = $account->user_id;
             if (empty($emailUserId)) {
@@ -2013,4 +2068,20 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
     {
         return Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($account, ['user_id' => 'user_id']);
     }
+
+    /**
+     * @param $account
+     * @param $grant
+     * @throws Tinebase_Exception_AccessDenied
+     */
+    public function checkGrantForSharedAccount($account, $grant)
+    {
+         // TODO generalize that? Tinebase_Core::getUser()->hasGrant() anyone?
+        $userGrants = Felamimail_Controller_Account::getInstance()->getGrantsOfAccount(Tinebase_Core::getUser(),
+            $account);
+        if (! $userGrants->{$grant} && ! $userGrants->{Felamimail_Model_AccountGrants::GRANT_ADMIN}) {
+            throw new Tinebase_Exception_AccessDenied(
+                'User is not allowed to send a message with this account');
+        }
+    }
 }
