@@ -6,7 +6,7 @@
  * @subpackage  Controller
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Lars Kneschke <l.kneschke@metaways.de>
- * @copyright   Copyright (c) 2007-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2020 Metaways Infosystems GmbH (http://www.metaways.de)
  * 
  */
 
@@ -20,7 +20,6 @@
  */
 class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract implements Tinebase_User_Plugin_SqlInterface
 {
-
     const CONTEXT_ALLOW_CREATE_USER = 'context_allow_create_user';
     const CONTEXT_NO_ACCOUNT_UPDATE = 'context_no_account_update';
     const CONTEXT_NO_SYNC_PHOTO = 'context_no_sync_photo';
@@ -33,6 +32,8 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
      */
     protected $_setGeoDataForContacts = FALSE;
 
+    protected $_addressFields = [];
+
     /**
      * configured syncBackends
      *
@@ -102,6 +103,27 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
         self::$_instance = null;
     }
 
+    public function search(Tinebase_Model_Filter_FilterGroup $_filter = NULL,
+                           Tinebase_Model_Pagination $_pagination = NULL,
+                           $_getRelations = FALSE,
+                           $_onlyIds = FALSE,
+                           $_action = self::ACTION_GET)
+    {
+        $result = parent::search($_filter, $_pagination, $_getRelations, $_onlyIds, $_action);
+        
+        if (!$_onlyIds && is_object(Tinebase_Core::getUser())) {
+            foreach ($result as $contact) {
+                if (!Tinebase_Core::getUser()->hasGrant(
+                        $contact->container_id, Addressbook_Model_ContactGrants::GRANT_PRIVATE_DATA) &&
+                    Tinebase_Core::getUser()->contact_id !== $contact->getId()) {
+                    $this->removePersonalData($contact);
+                };
+            }
+        }
+
+        return $result;
+    }
+
     public function get($_id, $_containerId = NULL, $_getRelatedData = TRUE, $_getDeleted = FALSE)
     {
         $contact = parent::get($_id, $_containerId, $_getRelatedData, $_getDeleted);
@@ -113,6 +135,14 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
         }
 
         Tinebase_CustomField::getInstance()->resolveRecordCustomFields($contact);
+        
+        // Remove personal data from contact if no grants. The user has always grants for his/her own contact
+        if (is_object(Tinebase_Core::getUser()) && !Tinebase_Core::getUser()->hasGrant(
+            $contact->container_id, Addressbook_Model_ContactGrants::GRANT_PRIVATE_DATA) &&
+            Tinebase_Core::getUser()->contact_id !== $contact->getId()) {
+            // Remove that personal data!
+            $contact = $this->removePersonalData($contact);
+        };
 
         return $contact;
     }
@@ -310,30 +340,7 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
      */
     protected function _inspectAfterUpdate($updatedRecord, $record, $currentRecord)
     {
-        if (($updatedRecord->email !== $currentRecord->email || (empty($updatedRecord->email) &&
-                $updatedRecord->email_home !== $currentRecord->email_home)) &&
-                count($listIds = Addressbook_Controller_List::getInstance()->getMemberships($updatedRecord)) > 0) {
-
-            $oldListAclCheck = Addressbook_Controller_List::getInstance()->doContainerACLChecks(false);
-            $raii = new Tinebase_RAII(function() use($oldListAclCheck) {
-                Addressbook_Controller_List::getInstance()->doContainerACLChecks($oldListAclCheck);
-            });
-
-            $lists = Addressbook_Controller_List::getInstance()->search(
-                Tinebase_Model_Filter_FilterGroup::getFilterForModel(Addressbook_Model_List::class, [
-                    ['field' => 'id', 'operator' => 'in', 'value' => $listIds],
-                    ['field' => 'xprops', 'operator' => 'contains', 'value' => Addressbook_Model_List::XPROP_USE_AS_MAILINGLIST],
-                ]));
-            foreach ($lists->filter(function($list) {
-                    return $list->xprops[Addressbook_Model_List::XPROP_USE_AS_MAILINGLIST];}) as $list) {
-                Tinebase_TransactionManager::getInstance()->registerAfterCommitCallback(function($list) {
-                    Felamimail_Sieve_AdbList::setScriptForList($list);
-                }, [$list]);
-            }
-
-            //for unused variable check
-            unset($raii);
-        }
+        $this->_updateMailinglistsOnEmailChange($updatedRecord, $currentRecord);
 
         if (isset($record->account_id) && !isset($updatedRecord->account_id)) {
             $updatedRecord->account_id = $record->account_id;
@@ -363,8 +370,7 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
         $updateSyncBackendIds = false;
 
         //get sync backends
-        foreach($this->getSyncBackends() as $backendId => $backendArray)
-        {
+        foreach($this->getSyncBackends() as $backendId => $backendArray) {
             if (isset($backendArray['filter'])) {
                 $oldACL = $this->doContainerACLChecks(false);
 
@@ -444,6 +450,38 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
         }
     }
 
+    protected function _updateMailinglistsOnEmailChange($updatedRecord, $currentRecord)
+    {
+        if (! Tinebase_Application::getInstance()->isInstalled('Felamimail')) {
+            return;
+        }
+
+        if (($updatedRecord->email !== $currentRecord->email || (empty($updatedRecord->email) &&
+                    $updatedRecord->email_home !== $currentRecord->email_home)) &&
+            count($listIds = Addressbook_Controller_List::getInstance()->getMemberships($updatedRecord)) > 0) {
+
+            $oldListAclCheck = Addressbook_Controller_List::getInstance()->doContainerACLChecks(false);
+            $raii = new Tinebase_RAII(function() use($oldListAclCheck) {
+                Addressbook_Controller_List::getInstance()->doContainerACLChecks($oldListAclCheck);
+            });
+
+            $lists = Addressbook_Controller_List::getInstance()->search(
+                Tinebase_Model_Filter_FilterGroup::getFilterForModel(Addressbook_Model_List::class, [
+                    ['field' => 'id', 'operator' => 'in', 'value' => $listIds],
+                    ['field' => 'xprops', 'operator' => 'contains', 'value' => Addressbook_Model_List::XPROP_USE_AS_MAILINGLIST],
+                ]));
+            foreach ($lists->filter(function($list) {
+                return $list->xprops[Addressbook_Model_List::XPROP_USE_AS_MAILINGLIST];}) as $list) {
+                Tinebase_TransactionManager::getInstance()->registerAfterCommitCallback(function($list) {
+                    Felamimail_Sieve_AdbList::setScriptForList($list);
+                }, [$list]);
+            }
+
+            //for unused variable check
+            unset($raii);
+        }
+    }
+
     /**
      * inspect creation of one record (after create)
      *
@@ -660,6 +698,13 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
             }
         }
 
+        if (!Tinebase_Core::getUser()->hasGrant(
+                $_record->container_id, Addressbook_Model_ContactGrants::GRANT_PRIVATE_DATA) &&
+            Tinebase_Core::getUser()->contact_id !== $_record->getId()) {
+            // We need to restore the data we previously removed
+            $_record = $this->removePersonalData($_record);
+        };
+
         // syncBackendIds is read only property!
         unset($_record->syncBackendIds);
     }
@@ -1179,6 +1224,9 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
             return;
         }
 
+        // $_updatedUser is the result of user sql backend load -> lacks "virtual" property container_id
+        $_updatedUser->container_id = $_newUserProperties->container_id;
+
         // update base information
         $contact = Tinebase_User::user2Contact($_updatedUser, clone $oldContact);
 
@@ -1285,4 +1333,31 @@ class Addressbook_Controller_Contact extends Tinebase_Controller_Record_Abstract
 
         return $contacts->getFirstRecord();
     }
+
+    /**
+     * Unset Personal data of a contact
+     * 
+     * @param Addressbook_Model_Contact $contact
+     * @return Addressbook_Model_Contact
+     */
+    private function removePersonalData(Addressbook_Model_Contact $contact) {
+        unset($contact->bday);
+        unset($contact->adr_two_countryname);
+        unset($contact->adr_two_locality);
+        unset($contact->adr_two_postalcode);
+        unset($contact->adr_two_region);
+        unset($contact->adr_two_street);
+        unset($contact->adr_two_street2);
+        unset($contact->adr_two_lon);
+        unset($contact->adr_two_lat);
+        unset($contact->email_home);
+        unset($contact->tel_home);
+        unset($contact->tel_cell_private);
+        unset($contact->tel_fax_home);
+        unset($contact->tel_home_normalized);
+        unset($contact->tel_cell_private_normalized);
+        unset($contact->tel_fax_home_normalized);
+
+        return $contact;
+    }
 }
