@@ -368,25 +368,27 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
 
         $userAgent = (isset($_message->headers['user-agent'])) ? $_message->headers['user-agent'] : NULL;
         $parameters = (isset($_partData['parameters'])) ? $_partData['parameters'] : array();
-        $decodedContent = $part->getDecodedContent();
+        $decodedContent = Tinebase_Core::filterInputForDatabase($part->getDecodedContent());
 
         switch ($part->type) {
             case Felamimail_Model_Message::CONTENT_TYPE_CALENDAR:
-                if (!version_compare(PHP_VERSION, '5.3.0', '>=')) {
-                    if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' PHP 5.3+ is needed for vcalendar support.');
-                    return NULL;
+                try {
+                    $partData = new Calendar_Model_iMIP(array(
+                        'id' => $_message->getId() . '_' . $_partId,
+                        'ics' => $decodedContent,
+                        'method' => (isset($parameters['method'])) ? $parameters['method'] : NULL,
+                        'originator' => $_message->from_email,
+                        'userAgent' => $userAgent,
+                    ));
+                } catch (Tinebase_Exception_Record_Validation $terv) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::WARN)) Tinebase_Core::getLogger()->warn(
+                        __METHOD__ . '::' . __LINE__ . ' Could not create iMIP: ' . $terv->getMessage());
+                    $partData = NULL;
                 }
-
-                $partData = new Calendar_Model_iMIP(array(
-                    'id' => $_message->getId() . '_' . $_partId,
-                    'ics' => $decodedContent,
-                    'method' => (isset($parameters['method'])) ? $parameters['method'] : NULL,
-                    'originator' => $_message->from_email,
-                    'userAgent' => $userAgent,
-                ));
                 break;
             default:
-                if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' Could not create iMIP of content type ' . $part->type);
+                if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                    __METHOD__ . '::' . __LINE__ . ' Could not create iMIP of content type ' . $part->type);
                 $partData = NULL;
         }
 
@@ -575,7 +577,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         $rawContent = '';
 
         // special handling for rfc822 messages
-        if ($_partId !== NULL && $_partStructure['contentType'] === Felamimail_Model_Message::CONTENT_TYPE_MESSAGE_RFC822) {
+        if ($_partId !== NULL && $_partStructure && $_partStructure['contentType'] === Felamimail_Model_Message::CONTENT_TYPE_MESSAGE_RFC822) {
             if ($_onlyBodyOfRfc822) {
                 $logmessage = 'Fetch message part (TEXT) ' . $_partId . ' of messageuid ' . $_message->messageuid;
                 if ((isset($_partStructure['messageStructure']) || array_key_exists('messageStructure', $_partStructure))) {
