@@ -86,15 +86,18 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         
         $result = $this->_userBackend->getUsers($_filter, $_sort, $_dir, $_start, $_limit, 'Tinebase_Model_FullUser');
 
-        $emailUser = null;
-        try {
-            $emailUser = Tinebase_EmailUser::getInstance();
-        } catch (Tinebase_Exception_NotFound $tenf) {}
+        if (Tinebase_EmailUser::manages(Tinebase_Config::IMAP)) {
+            $emailUser = null;
+            try {
+                $emailUser = Tinebase_EmailUser::getInstance();
+            } catch (Tinebase_Exception_NotFound $tenf) {
+            }
 
-        // FIXME if you want quota info: in Tinebase_User_Plugin_LdapInterface, inspectGetUserByProperty has a second param!
-        if (null !== $emailUser && ! $emailUser instanceof Tinebase_User_Plugin_LdapInterface ) {
-            foreach ($result as $user) {
-                $emailUser->inspectGetUserByProperty($user);
+            // FIXME if you want quota info: in Tinebase_User_Plugin_LdapInterface, inspectGetUserByProperty has a second param!
+            if (null !== $emailUser && !$emailUser instanceof Tinebase_User_Plugin_LdapInterface) {
+                foreach ($result as $user) {
+                    $emailUser->inspectGetUserByProperty($user);
+                }
             }
         }
         
@@ -126,9 +129,7 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
     {
         $this->checkRight('VIEW_ACCOUNTS');
         
-        $user = $this->_userBackend->getUserById($_userId, 'Tinebase_Model_FullUser');
-        
-        return $user;
+        return $this->_userBackend->getUserById($_userId, 'Tinebase_Model_FullUser');
     }
     
     /**
@@ -170,6 +171,10 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         if ($_password != $_passwordRepeat) {
             throw new Admin_Exception("Passwords don't match.");
         }
+
+        if ($_mustChange === null) {
+            $_mustChange = $_account->password_must_change ? true : false;
+        }
         
         $this->_userBackend->setPassword($_account, $_password, true, $_mustChange);
         
@@ -220,10 +225,12 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         $this->_checkLoginNameLength($_user);
         $this->_checkPrimaryGroupExistance($_user);
         $deactivated = false;
-        
+
+        $this->_checkSystemEmailAccountCreation($_user, $oldUser, $_password);
+
         if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
             __METHOD__ . '::' . __LINE__ . ' Update user ' . $_user->accountLoginName);
-        
+
         try {
             $transactionId = Tinebase_TransactionManager::getInstance()->startTransaction(Tinebase_Core::getDb());
             
@@ -264,7 +271,7 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         Tinebase_Event::fireEvent($event);
         
         if (!empty($_password) && !empty($_passwordRepeat)) {
-            $this->setAccountPassword($_user, $_password, $_passwordRepeat, FALSE);
+            $this->setAccountPassword($_user, $_password, $_passwordRepeat);
         }
 
         $this->_updateCurrentUser($user);
@@ -272,6 +279,23 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         return $user;
     }
 
+    /**
+     * @param $user
+     * @param $oldUser
+     * @param $password
+     * @throws Tinebase_Exception_SystemGeneric
+     */
+    protected function _checkSystemEmailAccountCreation($user, $oldUser, $password)
+    {
+        if (Tinebase_EmailUser::isEmailSystemAccountConfigured()
+            && empty($oldUser->accountEmailAddress)
+            && ! empty($user->accountEmailAddress)
+            && ! $password ) {
+            $translate = Tinebase_Translation::getTranslation('Admin');
+            throw new Tinebase_Exception_SystemGeneric($translate->_('Password is needed for system account creation'));
+        }
+    }
+
     /**
      * @param Tinebase_Model_FullUser $_user
      * @return Tinebase_Model_FullUser
