@@ -401,9 +401,11 @@ class Tinebase_Core
 
         $extract = Tinebase_Application::extractAppAndModel($_applicationName, $_modelName);
         $appName = $extract['appName'];
+        // appName property might be a Tinebase_Model_Application record here
+        $appNameString = ucfirst((string) $appName);
         $modelName = $extract['modelName'];
 
-        $controllerName = ucfirst((string) $appName);
+        $controllerName = $appNameString;
         if ($appName !== 'Tinebase' || ($appName === 'Tinebase' && ! $modelName)) {
             // only app controllers are called "App_Controller_Model"
             $controllerName .= '_Controller';
@@ -493,8 +495,21 @@ class Tinebase_Core
         }
 
         Tinebase_Core::setupContainer();
+        Tinebase_Core::setupDbLogger();
     }
 
+    protected static function setupDbLogger()
+    {
+        $config = self::getConfig();
+        
+        if ($config->dblogger) {
+            $logger = Tinebase_Core::getLogger();
+            $writer = $logger->getWriter($config->dblogger);
+            $writer->setFormatter($logger->getFormatter($config->dblogger));
+            $logger->addWriter($writer);
+        }
+    }
+    
     /**
      * setup DI container
      */
@@ -642,9 +657,9 @@ class Tinebase_Core
             $buildType = Tinebase_Core::detectBuildType();
         }
         define('TINE20_BUILDTYPE', $buildType);
-        define('TINE20_CODENAME',      '2019.12');
-        define('TINE20_PACKAGESTRING', '2019.12.5');
-        define('TINE20_RELEASETIME', '2020-02-20 15:16:37');
+        define('TINE20_CODENAME',      '2020.03');
+        define('TINE20_PACKAGESTRING', '2020.03.4');
+        define('TINE20_RELEASETIME', '2020-07-16 13:00:10');
     }
 
     /**
@@ -973,6 +988,8 @@ class Tinebase_Core
         try {
             $cache = Zend_Cache::factory('Core', $backendType, $frontendOptions, $backendOptions);
             if (($cacheBackend = $cache->getBackend()) instanceof Zend_Cache_Backend_Redis) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__
+                    . '::' . __LINE__ . ' Adding exception logger to Redis Backend');
                 $refProp = new ReflectionProperty(Zend_Cache_Backend_Redis::class, '_redis');
                 $refProp->setAccessible(true);
                 $refProp->getValue($cacheBackend)->setLogDelegator(function($exception) {
@@ -985,7 +1002,8 @@ class Tinebase_Core
 
             $enabled = false;
             if ('File' === $backendType && isset($backendOptions['cache_dir']) && ! is_dir($backendOptions['cache_dir'])) {
-                if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Create cache directory and re-try');
+                if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__
+                    . '::' . __LINE__ . ' Create cache directory and re-try');
                 if (@mkdir($backendOptions['cache_dir'], 0770, true)) {
                     $enabled = $_enabled;
                 }
@@ -2101,24 +2119,29 @@ class Tinebase_Core
     /**
      * get http client
      *
-     * @param null $uri
-     * @param null $config
+     * @param null|string $uri
+     * @param null|array $config
      * @return Zend_Http_Client
      */
     public static function getHttpClient($uri = null, $config = null)
     {
-        $proxyConfig = Tinebase_Config::getInstance()->get(Tinebase_Config::INTERNET_PROXY);
-        if (! empty($proxyConfig)) {
-            $proxyConfig['adapter'] = 'Zend_Http_Client_Adapter_Proxy';
-            if (is_array($config)) {
-                $config = array_merge($config, $proxyConfig);
-            } else {
-                $config = $proxyConfig;
+        if (! isset($config['noProxy']) || ! $config['noProxy']) {
+            $proxyConfig = Tinebase_Config::getInstance()->get(Tinebase_Config::INTERNET_PROXY);
+            if (!empty($proxyConfig)) {
+                $proxyConfig['adapter'] = 'Zend_Http_Client_Adapter_Proxy';
+                if (is_array($config)) {
+                    $config = array_merge($config, $proxyConfig);
+                } else {
+                    $config = $proxyConfig;
+                }
             }
         }
-        $httpClient = new Zend_Http_Client($uri, $config);
 
-        return $httpClient;
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+            __METHOD__ . '::' . __LINE__ . ' Creating Zend_Http_Client for ' . $uri . ' with config: '
+            . print_r($config, true));
+
+        return new Zend_Http_Client($uri, $config);
     }
 
     /**
