@@ -284,7 +284,7 @@ class Tinebase_EmailUser_Smtp_Postfix extends Tinebase_EmailUser_Sql implements
      */
     protected function _setAliasesAndForwards($_smtpSettings)
     {
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ 
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
             . ' Setting default alias/forward for ' . print_r($_smtpSettings, true));
         
         $this->_removeDestinations($_smtpSettings);
@@ -328,7 +328,9 @@ class Tinebase_EmailUser_Smtp_Postfix extends Tinebase_EmailUser_Sql implements
         ));
         
         // create username -> username alias if email and username are different
-        if ($_smtpSettings[$this->_propertyMapping['emailUsername']] != $_smtpSettings[$this->_propertyMapping['emailAddress']]) {
+        if ((! isset($this->_config['onlyemaildestination']) || ! $this->_config['onlyemaildestination'])
+            && $_smtpSettings[$this->_propertyMapping['emailUsername']] != $_smtpSettings[$this->_propertyMapping['emailAddress']]
+        ) {
             $this->_addDestination(array(
                 'userid'      => $_smtpSettings[$this->_propertyMapping['emailUserId']],   // userID
                 'source'      => $_smtpSettings[$this->_propertyMapping['emailUsername']], // username
@@ -344,7 +346,7 @@ class Tinebase_EmailUser_Smtp_Postfix extends Tinebase_EmailUser_Sql implements
      */
     protected function _addDestination($destinationData)
     {
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
             . ' Insert into table destinations: ' . print_r($destinationData, true));
 
         $schema = Tinebase_Db_Table::getTableDescriptionFromCache($this->_destinationTable, $this->_db);
@@ -714,4 +716,20 @@ class Tinebase_EmailUser_Smtp_Postfix extends Tinebase_EmailUser_Sql implements
 
         return (bool) $queryResult;
     }
+
+    /**
+     * copy email user
+     *
+     * @param Tinebase_Model_FullUser $_user
+     * @param string $newId
+     * @throws Tinebase_Exception
+     * @throws Zend_Db_Statement_Exception
+     * @return array
+     */
+    public function copyUser(Tinebase_Model_FullUser $_user, $newId)
+    {
+        $rawUser = parent::copyUser($_user, $newId);
+        $this->_createDefaultDestinations($rawUser);
+        return $rawUser;
+    }
 }
