@@ -116,13 +116,6 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
      */
     protected $_format = null;
 
-    /**
-     * custom field names for this model
-     *
-     * @var array
-     */
-    protected $_customFieldNames = null;
-
     /**
      * user fields to resolve
      *
@@ -202,16 +195,15 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
      */
     protected $_exportTimeStamp = null;
 
-    /**
-     * @var null|string
-     */
-    protected $_logoPath = null;
+    protected $_baseContext = null;
 
     /**
      * @var Tinebase_Record_RecordSet|null
      */
     protected $_records = null;
 
+    protected $_currentIterationRecords = null;
+
     protected $_lastGroupValue = null;
 
     protected $_groupByProperty = null;
@@ -284,8 +276,10 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
             $this->_applicationName = $this->_filter->getApplicationName();
         }
 
-        $this->_controller = ($_controller !== null) ? $_controller :
-            Tinebase_Core::getApplicationInstance($this->_applicationName, $this->_modelName, isset($_additionalOptions['ignoreACL']) && $_additionalOptions['ignoreACL']);
+        $this->_controller = ($_controller !== null)
+            ? $_controller
+            : $this->_getController(isset($_additionalOptions['ignoreACL']) && $_additionalOptions['ignoreACL']);
+
         $this->_translate = Tinebase_Translation::getTranslation($this->_applicationName);
         $this->_tinebaseTranslate = Tinebase_Translation::getTranslation('Tinebase');
         $this->_locale = Tinebase_Core::getLocale();
@@ -455,6 +449,15 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
         }
     }
 
+    protected function _getController($ignoreAcl = false)
+    {
+        return Tinebase_Core::getApplicationInstance(
+            $this->_applicationName,
+            $this->_modelName,
+            $ignoreAcl
+        );
+    }
+
     protected function _parseTemplatePath($_path)
     {
         if (strpos($_path, 'tine20://') !== 0) {
@@ -597,8 +600,15 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
      * @param string $_format
      * @return string
      */
-    public function getDownloadFilename($_appName, $_format)
+    public function getDownloadFilename($_appName = null, $_format = null)
     {
+        if (! $_appName) {
+            $_appName = $this->_applicationName;
+        }
+        if (! $_format) {
+            $_format = $this->_format;
+        }
+
         if (isset($this->_config->exportFilename) && $this->_hasTwig()) {
             $this->_twig->addLoader(new Twig_Loader_Array(['fileNameTmpl' => $this->_config->exportFilename]));
             $twigTmpl = $this->_twig->load('fileNameTmpl');
@@ -631,9 +641,11 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
             $name .= $this->_translate->_($this->_config->label, $this->_locale);
         }
         $tineTranslate = Tinebase_Translation::getTranslation('Tinebase');
-        $result =  mb_strtolower($tineTranslate->_('Export', $this->_locale) . '_' .
-            $this->_translate->_($_appName, $this->_locale) . $model . $name . '.' . $_format);
-        return str_replace(' ', '', $result);
+        $result = mb_strtolower($tineTranslate->plural('Export', 'Exports', 1, $this->_locale) . '_' .
+            $this->_translate->_($_appName, $this->_locale)
+            . ($model !== '' ? $model : '_')
+            . $name . '.' . $_format);
+        return str_replace([' ', '/'], '_', $result);
     }
 
 
@@ -826,7 +838,7 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
      *
      * @param Tinebase_Record_RecordSet|array $_records
      */
-    public function processIteration($_records)
+    public function processIteration($_records, $_resolveRecords = true)
     {
         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
             __METHOD__ . '::' . __LINE__ . ' iterating over export data...');
@@ -834,9 +846,15 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
         if (is_array($_records)) {
 
             foreach ($_records as $key => $value) {
+
+                $this->_currentIterationRecords = $value;
+                if ($_resolveRecords) {
+                    $this->_resolveRecords($value);
+                }
+
                 $this->_startDataSource($key);
 
-                $this->processIteration($value);
+                $this->processIteration($value, false);
 
                 $this->_endDataSource($key);
             }
@@ -844,7 +862,10 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
             return;
         }
 
-        $this->_resolveRecords($_records);
+        $this->_currentIterationRecords = $_records;
+        if ($_resolveRecords) {
+            $this->_resolveRecords($_records);
+        }
 
         if (true === $this->_firstIteration && true === $this->_writeGenericHeader) {
             $this->_writeGenericHead();
@@ -927,6 +948,12 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
         $this->_endRow();
     }
 
+    protected function _extendedCFResolving(Tinebase_Record_RecordSet $_records)
+    {
+        $_records->customfields = array();
+        Tinebase_CustomField::getInstance()->resolveMultipleCustomfields($_records, true);
+    }
+
     /**
      * resolve records and prepare for export (set user timezone, ...)
      *
@@ -997,8 +1024,7 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
             }
 
             if (!$this->_FEDataRecordResolving) {
-                $_records->customfields = array();
-                Tinebase_CustomField::getInstance()->resolveMultipleCustomfields($_records, true);
+                $this->_extendedCFResolving($_records);
             }
 
             $availableCFNames = [];
@@ -1046,11 +1072,13 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
                     }
                 }
                 foreach (array_diff_key($availableCFNames, $cfs) as $name => $cfc) {
-                    $cfs[$name] = clone $cfc;
+                    $cfs[$name] = $cfc;
                 }
 
                 array_walk($cfs, function(Tinebase_Model_CustomField_Config $val, $key)
                         use($cfNameLabelMap, $stringifyCallBack) {
+                    if ($val->value instanceof Tinebase_CustomField_Value) return;
+
                     $val->label = $cfNameLabelMap[$key];
                     $val->value = new Tinebase_CustomField_Value($val->value, $val->definition, $stringifyCallBack,
                         $val->application_id);
@@ -1194,6 +1222,10 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
 
         // TODO FE data resolving: what about this?
         foreach ((array)$this->_keyFields as $property => $keyField) {
+            if (!$_records->getFirstRecord()->has($property)) {
+                continue;
+            }
+
             /** @var Tinebase_Config_KeyField $keyField */
             if ($keyField['application'] === $this->_applicationName) {
                 $keyField = $appConfig->{$keyField['name']};
@@ -1352,6 +1384,8 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
 
     /**
      * @param Tinebase_Record_Interface $_record
+     *
+     * @todo @refactor split this up in multiple FNs
      */
     protected function _processRecord(Tinebase_Record_Interface $_record)
     {
@@ -1359,9 +1393,13 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
             __METHOD__ . '::' . __LINE__ . ' processing a export record...');
 
         if (true === $this->_dumpRecords) {
+            // TODO we should support "writing" whole records here and not only single fields - see \Calendar_Export_VCalendar
             foreach (empty($this->_fields) ? $_record->getFields() : $this->_fields as $field) {
                 if ($this->_rawData === false) {
-                    if ($this->_modelConfig && isset($this->_modelConfig->getFields()[$field]) && isset($this->_modelConfig->getFields()[$field]['system']) && $this->_modelConfig->getFields()[$field]['system'] === true) {
+                    if ($this->_modelConfig && isset($this->_modelConfig->getFields()[$field])
+                        && isset($this->_modelConfig->getFields()[$field]['system'])
+                        && $this->_modelConfig->getFields()[$field]['system'] === true
+                    ) {
                         continue;
                     } 
                 }
@@ -1400,7 +1438,8 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
         } elseif (null !== $this->_twigTemplate) {
             $this->_renderTwigTemplate($_record);
         } else {
-            if (Tinebase_Core::isLogLevel(Zend_Log::WARN)) Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' can not process record, misconfigured!');
+            if (Tinebase_Core::isLogLevel(Zend_Log::WARN)) Tinebase_Core::getLogger()->warn(
+                __METHOD__ . '::' . __LINE__ . ' can not process record, misconfigured!');
         }
     }
 
@@ -1436,41 +1475,50 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
      */
     protected function _getTwigContext(array $context)
     {
-        if (null === $this->_logoPath) {
-            $this->_logoPath = Tinebase_Core::getInstallLogo();
+        if (null === $this->_baseContext) {
+            $this->_baseContext = [
+                Addressbook_Config::INSTALLATION_REPRESENTATIVE => Addressbook_Config::getInstallationRepresentative(),
+                'branding' => [
+                    'logo' => Tinebase_Core::getInstallLogo(),
+                    'title' => Tinebase_Config::getInstance()->{Tinebase_Config::BRANDING_TITLE},
+                    'description' => Tinebase_Config::getInstance()->{Tinebase_Config::BRANDING_DESCRIPTION},
+                    'weburl' => Tinebase_Config::getInstance()->{Tinebase_Config::BRANDING_WEBURL},
+                ],
+                'export' => [
+                    'config' => $this->_config->toArray(),
+                    'timestamp' => $this->_exportTimeStamp,
+                    'account' => Tinebase_Core::getUser(),
+                    'contact' => Addressbook_Controller_Contact::getInstance()->getContactByUserId(Tinebase_Core::getUser()->getId()),
+                    'groupdata' => $this->_lastGroupValue,
+                ],
+                'additionalRecords' => $this->_additionalRecords,
+            ];
         }
+        $this->_baseContext['export']['groupdata'] = $this->_lastGroupValue;
 
-        $contact = Addressbook_Controller_Contact::getInstance()->getContactByUserId(Tinebase_Core::getUser()->getId());
-
-        return array_merge([
-            Addressbook_Config::INSTALLATION_REPRESENTATIVE => Addressbook_Config::getInstallationRepresentative(),
-            'branding' => [
-                'logo' => $this->_logoPath,
-                'title' => Tinebase_Config::getInstance()->{Tinebase_Config::BRANDING_TITLE},
-                'description' => Tinebase_Config::getInstance()->{Tinebase_Config::BRANDING_DESCRIPTION},
-                'weburl' => Tinebase_Config::getInstance()->{Tinebase_Config::BRANDING_WEBURL},
-            ],
-            'export' => [
-                'config'    => $this->_config->toArray(),
-                'timestamp' => $this->_exportTimeStamp,
-                'account'   => Tinebase_Core::getUser(),
-                'contact'   => $contact,
-                'groupdata' => $this->_lastGroupValue,
-            ],
-            'additionalRecords' => $this->_additionalRecords,
-        ], $context);
+        return array_merge($this->_baseContext, $context);
     }
 
     /**
+     * NOTE: do we need this to be abstract? some exports might not need this - for example Calendar_Export_VCalendar
+     *       -> so I remove the "abstract" here
+     *
      * @param string $_key
      * @param string $_value
      */
-    abstract protected function _setValue($_key, $_value);
+    protected function _setValue($_key, $_value)
+    {
+    }
 
     /**
+     * NOTE: do we need this to be abstract? some exports might not need this - for example Calendar_Export_VCalendar
+     *       -> so I remove the "abstract" here
+     *
      * @param string $_value
      */
-    abstract protected function _writeValue($_value);
+    protected function _writeValue($_value)
+    {
+    }
 
     /**
      * @param mixed $_value
@@ -1567,4 +1615,42 @@ abstract class Tinebase_Export_Abstract implements Tinebase_Record_IteratableInt
     {
         return $this->_controller;
     }
+
+    /**
+     * @return bool
+     *
+     * TODO remove code duplication with \Tinebase_Export_AbstractDeprecated::isDownload
+     */
+    public function isDownload()
+    {
+        return !$this->_config->returnFileLocation;
+    }
+
+    /**
+     * @param null|string $filename
+     * @return Tinebase_Model_Tree_FileLocation
+     * @throws Tinebase_Exception_NotImplemented
+     *
+     * TODO remove code duplication with \Tinebase_Export_AbstractDeprecated::getTargetFileLocation
+     */
+    public function getTargetFileLocation($filename = null)
+    {
+        if ($filename === null) {
+            if (method_exists($this, 'write')) {
+                ob_start();
+                $this->write();
+                $output = ob_get_clean();
+                $filename = Tinebase_TempFile::getTempPath();
+                file_put_contents($filename, $output);
+            } else {
+                throw new Tinebase_Exception_NotImplemented('Not implemented for this export');
+            }
+        }
+
+        $tempFile = Tinebase_TempFile::getInstance()->createTempFile($filename, $this->getDownloadFilename());
+        return new Tinebase_Model_Tree_FileLocation([
+            Tinebase_Model_Tree_FileLocation::FLD_TYPE => Tinebase_Model_Tree_FileLocation::TYPE_DOWNLOAD,
+            Tinebase_Model_Tree_FileLocation::FLD_TEMPFILE_ID => $tempFile->getId(),
+        ]);
+    }
 }
