@@ -49,6 +49,8 @@ class Tinebase_Export_Richtext_TemplateProcessor extends \PhpOffice\PhpWord\Temp
 
     protected $_postPCallMap = [];
 
+    protected $_twigTemplateSrc = null;
+
     /**
      * @param string $documentTemplate The fully qualified template filename.
      * @param bool   $inMemory
@@ -180,6 +182,24 @@ class Tinebase_Export_Richtext_TemplateProcessor extends \PhpOffice\PhpWord\Temp
         ];
     }
 
+    public function replaceTwigTemplate()
+    {
+        $this->_twigTemplateSrc = $this->findBlock('TWIG_TEMPLATE', '${TWIG_TEMPLATE}');
+        if (null !== $this->_twigTemplateSrc) {
+            $this->_twigTemplateSrc = $this->fixBrokenTwigMacros($this->_twigTemplateSrc);
+        }
+    }
+
+    public function unsetTwigSource()
+    {
+        $this->_twigTemplateSrc = null;
+    }
+
+    public function getTwigSource()
+    {
+        return $this->_twigTemplateSrc;
+    }
+
     /**
      * @return string
      */
@@ -567,9 +587,28 @@ class Tinebase_Export_Richtext_TemplateProcessor extends \PhpOffice\PhpWord\Temp
         }
         $endCloseBlockPos += 6;
 
+
         $xmlBlock = substr($this->tempDocumentMainPart, $endOpenBlockPos, $closeBlockPos - $endOpenBlockPos);
 
         if (null !== $replacement) {
+            $openBlockContent = substr($this->tempDocumentMainPart, $openBlockPos, $endOpenBlockPos - $openBlockPos);
+            $clsBlockContent = substr($this->tempDocumentMainPart, $closeBlockPos, $endCloseBlockPos - $closeBlockPos);
+
+            if (strip_tags($openBlockContent) !== $openBlock) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::INFO))
+                    Tinebase_Core::getLogger()->info(__METHOD__ . ' ' . __LINE__ . ' tag paragraph contains content: '
+                        . strip_tags($openBlockContent));
+                $openBlockContent = str_replace($openBlock, '', $openBlockContent);
+                $replacement = $openBlockContent . $replacement;
+            }
+            if (strip_tags($clsBlockContent) !== $closeBlock) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::INFO))
+                    Tinebase_Core::getLogger()->info(__METHOD__ . ' ' . __LINE__ . ' tag paragraph contains content: '
+                        . strip_tags($clsBlockContent));
+                $clsBlockContent = str_replace($closeBlock, '', $clsBlockContent);
+                $replacement .= $clsBlockContent;
+            }
+
             $this->tempDocumentMainPart = substr($this->tempDocumentMainPart, 0, $openBlockPos) . $replacement .
                 substr($this->tempDocumentMainPart, $endCloseBlockPos);
         }
@@ -702,4 +741,33 @@ class Tinebase_Export_Richtext_TemplateProcessor extends \PhpOffice\PhpWord\Temp
 
         return $fixedDocumentPart;
     }
+
+    /**
+     * Finds parts of broken macros and sticks them together.
+     * Macros, while being edited, could be implicitly broken by some of the word processors.
+     *
+     * @param string $documentPart The document part in XML representation.
+     *
+     * @return string
+     */
+    protected function fixBrokenTwigMacros($documentPart)
+    {
+        $fixedDocumentPart = preg_replace_callback(
+            '|\{[^}{%]*\{[^}]*\}[^}]*\}|U',
+            function ($match) {
+                return strip_tags($match[0]);
+            },
+            $documentPart
+        );
+
+        $fixedDocumentPart = preg_replace_callback(
+            '|\{[^}{%]*%[^}]*\}|U',
+            function ($match) {
+                return strip_tags($match[0]);
+            },
+            $fixedDocumentPart
+        );
+
+        return $fixedDocumentPart;
+    }
 }
