@@ -27,6 +27,20 @@ class Setup_Frontend_Cli
      */
     protected $_appname = 'Setup';
 
+    /**
+     * @var Tinebase_Application
+     */
+    protected $_tinebaseApplication;
+
+    public function __construct($tinebaseApplication = null)
+    {
+        if ($tinebaseApplication === null) {
+            $this->_tinebaseApplication = Tinebase_Application::getInstance();
+        } else {
+            $this->_tinebaseApplication = $tinebaseApplication;
+        }
+    }
+
     /**
      * authentication
      *
@@ -45,7 +59,7 @@ class Setup_Frontend_Cli
      *
      * @param Zend_Console_Getopt $_opts
      * @param boolean $exitAfterHandle
-     * @return void
+     * @return int
      */
     public function handle(Zend_Console_Getopt $_opts, $exitAfterHandle = true)
     {
@@ -80,6 +94,8 @@ class Setup_Frontend_Cli
             $result = $this->_install($_opts);
         } elseif(isset($_opts->update)) {
             $result = $this->_update($_opts);
+        } elseif(isset($_opts->update_needed)) {
+            $result = $this->_updateNeeded($_opts);
         } elseif(isset($_opts->uninstall)) {
             $this->_uninstall($_opts);
         } elseif(isset($_opts->install_dump)) {
@@ -122,6 +138,10 @@ class Setup_Frontend_Cli
             $this->_upgradeMysql564();
         } elseif(isset($_opts->migrateUtf8mb4)) {
             $this->_migrateUtf8mb4();
+        } elseif(isset($_opts->config_from_env)) {
+            $this->_configFromEnv();
+        } elseif(isset($_opts->is_installed)) {
+            $result = $this->_isInstalled();
         }
 
         Tinebase_Log::logUsageAndMethod('setup.php', $time_start, 'Setup.' . implode(',', $_opts->getOptions()));
@@ -129,6 +149,8 @@ class Setup_Frontend_Cli
         if ($exitAfterHandle) {
             exit($result);
         }
+
+        return $result;
     }
     
     /**
@@ -170,13 +192,13 @@ class Setup_Frontend_Cli
         }
 
         $this->_promptRemainingOptions($applications, $options);
-        $controller->installApplications($applications, $options);
+        $appCount = $controller->installApplications($applications, $options);
         
         if ((isset($options['acceptedTermsVersion']) || array_key_exists('acceptedTermsVersion', $options))) {
             Setup_Controller::getInstance()->saveAcceptedTerms($options['acceptedTermsVersion']);
         }
         
-        echo "Successfully installed " . count($applications) . " applications.\n";
+        echo "Successfully installed " . $appCount . " applications.\n";
         return 0;
     }
 
@@ -451,6 +473,23 @@ class Setup_Frontend_Cli
     {
         $result = Setup_Controller::getInstance()->updateApplications();
         echo "Updated " . $result['updated'] . " application(s).\n";
+        if ($_opts->v && count($result['updates']) > 0) {
+            print_r($result['updates']);
+        }
+        return 0;
+    }
+
+    /**
+     * @param Zend_Console_Getopt $_opts
+     * @return int
+     */
+    protected function _updateNeeded(Zend_Console_Getopt $_opts)
+    {
+        $result = Setup_Controller::getInstance()->updateNeeded();
+        if ($result) {
+            echo "Update required\n";
+            return 1;
+        }
         return 0;
     }
 
@@ -617,6 +656,7 @@ class Setup_Frontend_Cli
         }
         
         echo "Currently installed applications:\n";
+        $applications->sort('name');
         foreach ($applications as $application) {
             echo "* " . $application->name . " (Version: " . $application->version . ")\n";
         }
@@ -1271,4 +1311,70 @@ class Setup_Frontend_Cli
 
         Setup_Controller::getInstance()->clearCache();
     }
+
+    /**
+     * loads config values from environment
+     */
+    private function _configFromEnv()
+    {
+        $output = [];
+
+        foreach ($_ENV as $env_key => $env_value) {
+            $env_key_array = explode('_', $env_key);
+            if ($env_key_array[0] != 'TINE20' || ! isset($env_key_array[1]) || $env_key_array[1] != '' || ! isset($env_key_array[2])) {
+                //Only accept env vars with format 'TINE20__*'
+                continue;
+            }
+
+            if (isset($env_key_array[3])) {
+                $applicationName = $env_key_array[2];
+                $configKey = $env_key_array[3];
+            } else {
+                $applicationName = 'Tinebase';
+                $configKey = $env_key_array[2];
+            }
+
+            $configValue = self::parseConfigValue($env_value);
+
+            if (! Tinebase_Application::getInstance()->isInstalled('Tinebase') || ! Tinebase_Application::getInstance()->isInstalled($applicationName)) {
+                $output[] = $configKey . " err: " . $applicationName . ' is not installed';
+                continue;
+            }
+
+            $config = Tinebase_Config_Abstract::factory($applicationName);
+
+            if (null === $config->getDefinition($configKey)) {
+                $output[] = $configKey . " err: config property does not exist in " . $applicationName;
+                continue;
+            }
+
+            if ($config->get($configKey) == $configValue) {
+                $output[] = $configKey . " ok";
+                continue;
+            }
+
+            $config->set($configKey, $configValue);
+            $output[] = $configKey . " changed";
+        }
+
+        if (! empty($output)) {
+            foreach ($output as $lines) {
+                echo "- " . $lines . "\n";
+            }
+        } else {
+            echo "Nothing to load\n";
+        }
+    }
+
+    private function _isInstalled() {
+        try {
+            if ($this->_tinebaseApplication->isInstalled('Tinebase', true)) {
+                return 0;
+            }
+        } catch (Exception $e) {
+            return 1;
+        }
+
+        return 1;
+    }
 }
