@@ -514,6 +514,9 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
 
             echo "\nCleaning notes...";
             $this->cleanNotes($_opts);
+
+            echo "\nCleaning files...";
+            $this->clearDeletedFiles();
         }
 
         echo "\n\n";
@@ -984,6 +987,64 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
         return 0;
     }
 
+    /**
+     * set node acl
+     *
+     * example:
+     * $ php tine20.php --method Tinebase.setNodeAcl [-d] -- id=NODEID \
+     *   grants='[{"account":"$USERNAME","account_type":"user","readGrant":1,"writeGrant":1},{"account":"$GROUPNAME","account_type":"group","readGrant":1}]'
+     *
+     * @param $_opts
+     * @return integer
+     *
+     * @todo generalize this - see \Tinebase_Frontend_Cli::setCustomfieldAcl
+     * @todo add a test
+     */
+    public function setNodeAcl(Zend_Console_Getopt $_opts)
+    {
+        $this->_checkAdminRight();
+
+        $args = $this->_parseArgs($_opts, ['id', 'grants'], 'other', false);
+        $node = Tinebase_FileSystem::getInstance()->get($args['id']);
+
+        $grantsArray = Tinebase_Helper::jsonDecode($args['grants']);
+        #print_r($grantsArray);
+        // @todo generalize this - see \Tinebase_Frontend_Cli::setCustomfieldAcl
+        $grantsToSet = new Tinebase_Record_RecordSet(Tinebase_Model_Grants::class);
+        foreach ($grantsArray as $grant) {
+            $accountType = isset($grant['account_type']) ? $grant['account_type'] : Tinebase_Acl_Rights::ACCOUNT_TYPE_USER;
+            if (isset($grant['account'])) {
+                if ($accountType === Tinebase_Acl_Rights::ACCOUNT_TYPE_GROUP) {
+                    $group = Tinebase_Group::getInstance()->getGroupByName($grant['account']);
+                    $accountId = $group->getId();
+                } else {
+                    $user = Tinebase_User::getInstance()->getFullUserByLoginName($grant['account']);
+                    $accountId = $user->getId();
+                }
+            } else {
+                $accountId = isset($grant['account_id']) ? $grant['account_id'] : null;
+            }
+            $grantRecord = new Tinebase_Model_Grants([
+                'account_id' => $accountId,
+                'account_type' => $accountType,
+            ]);
+            foreach (Tinebase_Model_Grants::getAllGrants() as $possibleGrant) {
+                if (isset($grant[$possibleGrant])) {
+                    $grantRecord->{$possibleGrant} = (boolean) $grant[$possibleGrant];
+                }
+            }
+            $grantsToSet->addRecord($grantRecord);
+        }
+        if ($_opts->d) {
+            echo "DRYRUN! grants to be set:\n";
+            print_r($grantsToSet->toArray());
+        } else {
+            Tinebase_FileSystem::getInstance()->setGrantsForNode($node, $grantsToSet);
+        }
+
+        return 0;
+    }
+
     /**
      * nagios monitoring for tine 2.0 database connection
      * 
@@ -1030,26 +1091,9 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
     public function monitoringCheckConfig()
     {
         $message = 'CONFIG FAIL';
-        $configcheck = FALSE;
+        $configcheck = Tinebase_Controller::getInstance()->checkConfig();
         $result = 0;
-        
-        $configfile = Setup_Core::getConfigFilePath();
-        if ($configfile) {
-            $configfile = escapeshellcmd($configfile);
-            if (preg_match('/^win/i', PHP_OS)) {
-                exec("php -l $configfile 2> NUL", $error, $code);
-            } else {
-                exec("php -l $configfile 2> /dev/null", $error, $code);
-            }
-            if ($code == 0) {
-                $configcheck = TRUE;
-            } else {
-                $message .= ': CONFIG FILE SYNTAX ERROR';
-            }
-        } else {
-            $message .= ': CONFIG FILE MISSING';
-        }
-        
+
         if ($configcheck) {
             $message = "CONFIG FILE OK";
         } else {
@@ -1115,7 +1159,7 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
     }
     
     /**
-     * nagios monitoring for tine 2.0 logins during the last 5 mins
+     * nagios monitoring for successful tine 2.0 logins during the last 5 mins
      * 
      * @return number
      * 
@@ -1128,7 +1172,8 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
         
         try {
             $filter = new Tinebase_Model_AccessLogFilter(array(
-                array('field' => 'li', 'operator' => 'after', 'value' => Tinebase_DateTime::now()->subMinute(5))
+                array('field' => 'li', 'operator' => 'after', 'value' => Tinebase_DateTime::now()->subMinute(5)),
+                array('field' => 'result', 'operator' => 'equals', 'value' => 1),
             ));
             $accesslogs = Tinebase_AccessLog::getInstance()->search($filter, NULL, FALSE, TRUE);
             $valueString = ' | count=' . count($accesslogs) . ';;;;';
@@ -1329,184 +1374,51 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
                         $queueState = [
                             'lastFullCheck' => 0,
                             'lastSizeOver10k' => false,
-                            'lastMissingQueueKeys' => [],
-                            'lastMissingDaemonKeys' => [],
+                            'actionQueueMissingQueueKeys' => [],
+                            'actionQueueMissingDaemonKeys' => [],
                             'lastLRSizeOver10k' => false,
-                            'lastLRMissingQueueKeys' => [],
-                            'lastLRMissingDaemonKeys' => [],
+                            'actionQueueLRMissingQueueKeys' => [],
+                            'actionQueueLRMissingDaemonKeys' => [],
                         ];
                     }
 
                     $queueSize = $actionQueue->getQueueSize();
-                    if (null === $warn && $actionQueue->getDaemonStructSize() > 12) {
-                        $warn = 'daemon struct size > 12';
+                    if (null === $warn && $actionQueue->getDaemonStructSize() > $queueConfig
+                            ->{Tinebase_Config::ACTIONQUEUE_MONITORING_DAEMONSTRCTSIZE_CRIT}) {
+                        $warn = 'daemon struct size > ' . $queueConfig
+                                ->{Tinebase_Config::ACTIONQUEUE_MONITORING_DAEMONSTRCTSIZE_CRIT};
                     }
 
                     $queueSizeLR = $actionLRQueue->getQueueSize();
-                    if (null === $warn && $actionLRQueue->getDaemonStructSize() > 2) {
-                        $warn = 'LR daemon struct size > 2';
+                    if (null === $warn && $actionLRQueue->getDaemonStructSize() > $queueConfig
+                            ->{Tinebase_Config::ACTIONQUEUE_LR_MONITORING_DAEMONSTRCTSIZE_CRIT}) {
+                        $warn = 'LR daemon struct size > ' . $queueConfig
+                                ->{Tinebase_Config::ACTIONQUEUE_LR_MONITORING_DAEMONSTRCTSIZE_CRIT};
                     }
 
                     // last full check older than one hour
                     if (null === $warn && time() - $queueState['lastFullCheck'] > 3600) {
-                        do {
-
-                            $missingQueueKeys = [];
-                            $missingDaemonKeys = [];
-                            $err = null;
-                            // go through queue and daemon struct and check timestamps in data
-                            // remember stuff we did not find
-                            foreach ($actionQueue->getQueueKeys() as $key) {
-                                if (empty($data = $actionQueue->getData($key))) {
-                                    if (isset($queueState['lastMissingQueueKeys'][$key])) {
-                                        if (null === $warn) {
-                                            $warn = 'queue contains keys which are not present in data';
-                                        }
-                                    } else {
-                                        $missingQueueKeys[$key] = true;
-                                    }
-                                } else {
-                                    if (($timediff = time() - $data['time']) > 15 * 60) {
-                                        if (null === $warn) {
-                                            $warn = 'data contains data older than 15 minutes';
-                                        }
-                                    }
-                                    if ($timediff > 60 * 60) {
-                                        $err = 'data contains data older than 1 hour';
-                                    }
-                                }
+                        if ($queueSize > 10000) {
+                            if (null === $warn && $queueState['lastSizeOver10k']) {
+                                $warn = 'at least two consecutive full checks with queue size > 10k';
                             }
-                            $queueState['lastMissingQueueKeys'] = $missingQueueKeys;
+                            $queueState['lastSizeOver10k'] = true;
+                        } else {
+                            $queueState['lastSizeOver10k'] = false;
+                        }
 
-                            foreach ($actionQueue->getDaemonStructKeys() as $key) {
-                                if (empty($data = $actionQueue->getData($key))) {
-                                    if (isset($queueState['lastMissingDaemonKeys'][$key])) {
-                                        if (null === $warn) {
-                                            $warn = 'daemon contains keys which are not present in data';
-                                        }
-                                    } else {
-                                        $missingDaemonKeys[$key] = true;
-                                    }
-                                } else {
-                                    if (($timediff = time() - $data['time']) > 15 * 60) {
-                                        if (null === $warn) {
-                                            $warn = 'data contains data older than 15 minutes';
-                                        }
-                                    }
-                                    if ($timediff > 60 * 60) {
-                                        $err = 'data contains data older than 1 hour';
-                                    }
-                                }
+                        if ($queueSizeLR > 10000) {
+                            if (null === $warn && $queueState['lastLRSizeOver10k']) {
+                                $warn = 'LR at least two consecutive full checks with queue size > 10k';
                             }
-                            $queueState['lastMissingDaemonKeys'] = $missingDaemonKeys;
+                            $queueState['lastLRSizeOver10k'] = true;
+                        } else {
+                            $queueState['lastLRSizeOver10k'] = false;
+                        }
 
-                            // go through data keys and check timestmaps
-                            while (false !== ($data = $actionQueue->iterateAllData())) {
-                                foreach ($data as $jobId) {
-                                    if (!empty($job = $actionQueue->getData($jobId))) {
-                                        if (($timediff = time() - $job['time']) > 15 * 60) {
-                                            if (null === $warn) {
-                                                $warn = 'data contains data older than 15 minutes';
-                                            }
-                                        }
-                                        if ($timediff > 60 * 60) {
-                                            $err = 'data contains data older than 1 hour';
-                                        }
-                                    }
-                                }
-                            }
-
-                            if ($queueSize > 10000) {
-                                if (null === $warn && $queueState['lastSizeOver10k']) {
-                                    $warn = 'at least two consecutive full checks with queue size > 10k';
-                                }
-                                $queueState['lastSizeOver10k'] = true;
-                            } else {
-                                $queueState['lastSizeOver10k'] = false;
-                            }
-
-
-                            // do LR
-
-                            $missingLRQueueKeys = [];
-                            $missingLRDaemonKeys = [];
-                            // go through queue and daemon struct and check timestamps in data
-                            // remember stuff we did not find
-                            foreach ($actionLRQueue->getQueueKeys() as $key) {
-                                if (empty($data = $actionLRQueue->getData($key))) {
-                                    if (isset($queueState['lastLRMissingQueueKeys'][$key])) {
-                                        if (null === $warn) {
-                                            $warn = 'LR queue contains keys which are not present in data';
-                                        }
-                                    } else {
-                                        $missingLRQueueKeys[$key] = true;
-                                    }
-                                } else {
-                                    if (($timediff = time() - $data['time']) > 60 * 60) {
-                                        if (null === $warn) {
-                                            $warn = 'LR data contains data older than 60 minutes';
-                                        }
-                                    }
-                                    if ($timediff > 5 * 60 * 60) {
-                                        $err = 'LR data contains data older than 5 hour';
-                                    }
-                                }
-                            }
-                            $queueState['lastLRMissingQueueKeys'] = $missingLRQueueKeys;
-
-                            foreach ($actionLRQueue->getDaemonStructKeys() as $key) {
-                                if (empty($data = $actionLRQueue->getData($key))) {
-                                    if (isset($queueState['lastLRMissingDaemonKeys'][$key])) {
-                                        if (null === $warn) {
-                                            $warn = 'LR daemon contains keys which are not present in data';
-                                        }
-                                    } else {
-                                        $missingLRDaemonKeys[$key] = true;
-                                    }
-                                } else {
-                                    if (($timediff = time() - $data['time']) > 60 * 60) {
-                                        if (null === $warn) {
-                                            $warn = 'LR data contains data older than 60 minutes';
-                                        }
-                                    }
-                                    if ($timediff > 5 * 60 * 60) {
-                                        $err = 'LR data contains data older than 5 hour';
-                                    }
-                                }
-                            }
-                            $queueState['lastLRMissingDaemonKeys'] = $missingLRDaemonKeys;
-
-                            // go through data keys and check timestmaps
-                            while (false !== ($data = $actionLRQueue->iterateAllData())) {
-                                foreach ($data as $jobId) {
-                                    if (!empty($job = $actionLRQueue->getData($jobId))) {
-                                        if (($timediff = time() - $job['time']) > 60 * 60) {
-                                            if (null === $warn) {
-                                                $warn = 'LR data contains data older than 60 minutes';
-                                            }
-                                        }
-                                        if ($timediff > 5 * 60 * 60) {
-                                            $err = 'data contains data older than 5 hour';
-                                        }
-                                    }
-                                }
-                            }
-
-                            if ($queueSizeLR > 10000) {
-                                if (null === $warn && $queueState['lastLRSizeOver10k']) {
-                                    $warn = 'LR at least two consecutive full checks with queue size > 10k';
-                                }
-                                $queueState['lastLRSizeOver10k'] = true;
-                            } else {
-                                $queueState['lastLRSizeOver10k'] = false;
-                            }
-
-                            $queueState['lastFullCheck'] = time();
-                            Tinebase_Application::getInstance()->setApplicationState('Tinebase',
-                                Tinebase_Application::STATE_ACTION_QUEUE_STATE, json_encode($queueState));
-
-                            if (null !== $err) throw new Tinebase_Exception($err);
-                        } while (false);
+                        $queueState['lastFullCheck'] = time();
+                        Tinebase_Application::getInstance()->setApplicationState('Tinebase',
+                            Tinebase_Application::STATE_ACTION_QUEUE_STATE, json_encode($queueState));
                     }
 
                     if (null !== $warn) {
@@ -1578,15 +1490,19 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
                 // TODO add cache access time?
 
                 // write, read and delete to test cache
-                $cacheId = Tinebase_Helper::convertCacheId(__METHOD__);
-                $cache->save(true, $cacheId);
-                $value = $cache->load($cacheId);
-                $cache->remove($cacheId);
+                $cacheId = Tinebase_Helper::convertCacheId(uniqid(__METHOD__, true));
+                if (false !== $cache->save(true, $cacheId)) {
+                    $value = $cache->load($cacheId);
+                    $cache->remove($cacheId);
 
-                if ($value) {
-                    $message = 'CACHE OK | size=' . $cacheSize . ';;;;';
+                    if ($value) {
+                        $message = 'CACHE OK | size=' . $cacheSize . ';;;;';
+                    } else {
+                        $message = 'CACHE FAIL: loading value failed';
+                        $result = 1;
+                    }
                 } else {
-                    $message = 'CACHE FAIL: loading value failed';
+                    $message = 'CACHE FAIL: saving value failed';
                     $result = 1;
                 }
             } catch (Exception $e) {
@@ -1776,6 +1692,40 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
         return 0;
     }
 
+    /**
+     * repair acl of nodes (supports -d for dry run)
+     *
+     * @param $opts
+     * @return int
+     * @throws ReflectionException
+     * @throws Tinebase_Exception_InvalidArgument
+     * @throws Tinebase_Exception_NotFound
+     * @throws Tinebase_Exception_Record_Validation
+     * @throws Zend_Db_Statement_Exception
+     */
+    public function repairFileSystemAclNodes($opts)
+    {
+        $this->_checkAdminRight();
+
+        $fs = Tinebase_FileSystem::getInstance();
+        $counter = 0;
+        foreach (Tinebase_Core::getDb()->query('SELECT tnchild.id, tnparent.acl_node FROM ' .
+                SQL_TABLE_PREFIX . 'tree_nodes as tnchild JOIN ' . SQL_TABLE_PREFIX .
+                'tree_nodes as tnparent ON tnchild.parent_id = tnparent.id WHERE tnparent.acl_node IS NOT NULL '
+                . 'AND tnchild.acl_node IS NULL')->fetchAll() as $row) {
+
+            if ($opts->d) {
+                echo "repairing acl of node id " . $row['id'] . PHP_EOL;
+            } else {
+                $fs->repairAclOfNode($row['id'], $row['acl_node']);
+            }
+            $counter++;
+        }
+        echo "repaired $counter nodes" . PHP_EOL;
+
+        return 0;
+    }
+
     /**
      * recalculates the revision sizes and then the folder sizes
      *
@@ -1818,6 +1768,7 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
     {
         $this->_checkAdminRight();
 
+        Tinebase_FileSystem_Previews::getInstance()->resetErrorCount();
         Tinebase_FileSystem::getInstance()->sanitizePreviews();
 
         return 0;
@@ -1832,7 +1783,6 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
     {
         $this->_checkAdminRight();
 
-        // TODO reset preview_error_count
         Tinebase_FileSystem_Previews::getInstance()->deleteAllPreviews();
         Tinebase_FileSystem::getInstance()->sanitizePreviews();
 
@@ -2193,20 +2143,75 @@ class Tinebase_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
         Tinebase_FileSystem::getInstance()->repairTreeIsDeletedState();
     }
 
+
     /**
-     * activate saving of email user id in xprops and converts existing accounts
+     * set Maintenance Mode
+     *
+     * @param Zend_Console_Getopt $_opts
+     * @throws Tinebase_Exception_AccessDenied
+     * @throws Tinebase_Exception_InvalidArgument
+     * @throws Tinebase_Exception_NotFound
      */
-    public function emailUserIdInXprops()
+    public function setMaintenanceMode(Zend_Console_Getopt $_opts)
     {
         $this->_checkAdminRight();
+        $args = $this->_parseArgs($_opts);
+        $enable = null;
 
-        if (Tinebase_Application::getInstance()->isInstalled('Felamimail')) {
-            Felamimail_Controller_Account::getInstance()->convertAccountsToSaveUserIdInXprops();
+        if (! isset($args['other'])) {
+            echo 'option Maintenance Mode is not set';
+            return 1;
+        }
+        if (in_array('on', $args['other'])) {
+            $enable = true;
+        }
+        if (in_array('off', $args['other'])) {
+            if (true === $enable) {
+                echo 'duplicated Maintenance Mode';
+                return 2;
+            }
+
+            $enable = false;
+        }
+        if (null === $enable) {
+            echo 'option Maintenance Mode is not set';
+            return 1;
         }
 
-        Admin_Controller_User::getInstance()->convertAccountsToSaveUserIdInXprops();
 
-        // activate config
-        Tinebase_Config::getInstance()->{Tinebase_Config::EMAIL_USER_ID_IN_XPROPS} = true;
+        $enabledApplications = Tinebase_Application::getInstance()->getApplicationsByState(Tinebase_Application::ENABLED);
+
+        foreach ($enabledApplications as $application) {
+            $app = Tinebase_Core::getApplicationInstance($application->name);
+
+            if (true === $enable) {
+                $app->goIntoMaintenanceMode();
+            } else {
+                $app->leaveMaintenanceMode();
+            }
+        }
+
+        echo PHP_EOL . ($enable ? 'going into' : 'leaving') . ' maintenance mode. waiting...' . PHP_EOL;
+
+        do {
+            foreach ($enabledApplications as $application) {
+                $app = Tinebase_Core::getApplicationInstance($application->name);
+
+                if ($app->isInMaintenanceMode() === $enable) {
+                    $enabledApplications->removeById($application->id);
+                }
+            }
+
+            if ($enabledApplications->count() > 0) {
+                echo '.';
+                usleep(100000);
+            }
+
+        } while ($enabledApplications->count() > 0);
+        echo 'done' . PHP_EOL;
+        return 0;
     }
 }
+
+
+
