@@ -42,7 +42,8 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     protected $_configuredModels = [
         'BLConfig',
-        'ImportExportDefinition'
+        'ImportExportDefinition',
+        'LogEntry',
     ];
 
     /**
@@ -865,6 +866,7 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 'releaseTime'   => TINE20_RELEASETIME,
                 'assetHash'     => $assetHash,
             ),
+            'setupRequired'     => Setup_Controller::getInstance()->setupRequired(),
             'defaultUsername'   => $defaultUsername,
             'defaultPassword'   => $defaultPassword,
             'denySurveys'       => Tinebase_Core::getConfig()->denySurveys,
@@ -1058,8 +1060,9 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
 
         // @todo do this for all apps at once (see import definitions)
         $exportDefinitions = Tinebase_ImportExportDefinition::getInstance()->getExportDefinitionsForApplication($application);
+        $definitionConverter = new Tinebase_Convert_ImportExportDefinition_Json();
         $appRegistry['exportDefinitions'] = array(
-            'results'               => $exportDefinitions->toArray(),
+            'results'               => $definitionConverter->fromTine20RecordSet($exportDefinitions),
             'totalcount'            => count($exportDefinitions),
         );
 
@@ -1589,6 +1592,39 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $state == Tinebase_Core::getPreference()->getValue(Tinebase_Preference::ADVANCED_SEARCH, 0);
     }
 
+    public function restoreRevision($fileLocationSrc, $fileLocationTrgt = null)
+    {
+        $src = new Tinebase_Model_Tree_FileLocation($fileLocationSrc);
+        $fs = Tinebase_FileSystem::getInstance();
+
+        $transId = Tinebase_TransactionManager::getInstance()->startTransaction(Tinebase_Core::getDb());
+        // if $transId is not set to null, rollback. note the & pass-by-ref! otherwise it would not work
+        $raii = (new Tinebase_RAII(function() use (&$transId) {
+            if (null !== $transId) {
+                Tinebase_TransactionManager::getInstance()->rollBack();
+            }
+        }))->setReleaseFunc(function () use (&$transId) {
+            Tinebase_TransactionManager::getInstance()->commitTransaction($transId);
+            $transId = null;
+        });
+
+        $node = $src->getNode();
+
+        if (null === $fileLocationTrgt) {
+            if ($node->getHighestRevision() > $node->revision && ($currentNode = $fs->get($node->getId()))->hash !==
+                    $node->hash) {
+                $currentNode->hash = $node->hash;
+                $fs->update($currentNode);
+            }
+        } else {
+            $trgt = new Tinebase_Model_Tree_FileLocation($fileLocationTrgt);
+            $trgt->copyNodeTo($node);
+        }
+
+        $raii->release();
+        return ['success' => true];
+    }
+
     /**
      * returns the replication modification logs
      *
