@@ -341,6 +341,11 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         if (! empty($password)) {
             Tinebase_Core::getLogger()->addReplacement($password);
         }
+
+        // dehydrate primary group id
+        if (is_array($recordData['accountPrimaryGroup']) && isset($recordData['accountPrimaryGroup']['id'])) {
+            $recordData['accountPrimaryGroup']= $recordData['accountPrimaryGroup']['id'];
+        }
         
         $account = new Tinebase_Model_FullUser();
         
@@ -796,7 +801,6 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         
         if ($tagId) {
             $tag = Admin_Controller_Tags::getInstance()->get($tagId)->toArray();
-            //$tag->rights = $tag->rights->toArray();
             $tag['rights'] = self::resolveAccountName($tag['rights'] , true);
         }
         $tag['appList'] = Tinebase_Application::getInstance()->getApplicationsByState(Tinebase_Application::ENABLED)->toArray();
@@ -1330,6 +1334,55 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $this->_delete($ids, Admin_Controller_EmailAccount::getInstance());
     }
 
+    /****************************** LogEntry ******************************/
+
+    /**
+     * Search for records matching given arguments
+     *
+     * @param array $filter
+     * @param array $paging
+     * @return array
+     */
+    public function searchLogEntrys($filter, $paging)
+    {
+        $result = $this->_search($filter, $paging, Admin_Controller_LogEntry::getInstance(), 'Tinebase_Model_LogEntryFilter');
+
+        return $result;
+    }
+
+    /**
+     * Return a single record
+     *
+     * @param   string $id
+     * @return  array record data
+     */
+    public function getLogEntry($id)
+    {
+        return $this->_get($id, Admin_Controller_LogEntry::getInstance());
+    }
+
+    /**
+     * creates/updates a record
+     *
+     * @param  array $recordData
+     * @return array created/updated record
+     */
+    public function saveLogEntry($recordData)
+    {
+        return $this->_save($recordData, Admin_Controller_LogEntry::getInstance(), 'Tinebase_Model_LogEntry');
+    }
+
+    /**
+     * deletes existing records
+     *
+     * @param  array  $ids
+     * @return string
+     */
+    public function deleteLogEntrys($ids)
+    {
+        return $this->_delete($ids, Admin_Controller_LogEntry::getInstance());
+    }
+
 
     /****************************** other *******************************/
     
@@ -1377,28 +1430,36 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         }
         $virtualPath = $emailPath . '/Emails';
         $path = '';
+        $pathArray = null;
         if (null !== $filter) {
-            array_walk($filter, function ($val) use (&$path) {
+            $key = null;
+            array_walk($filter, function ($val, $k) use (&$path, &$pathArray, &$key) {
                 if ('path' === $val['field']) {
                     $path = $val['value'];
+                    $pathArray = $val;
+                    $key = $k;
                 }
             });
+            if (null !== $key) {
+                unset($filter[$key]);
+            }
         }
 
         if ($isFelamimailInstalled && strpos($path, $virtualPath) === 0) {
             $records = $this->_getVirtualEmailQuotaNodes(str_replace($virtualPath, '', $path));
             $filterArray = $filter;
+            if (null !== $pathArray) {
+                $filterArray[] = $pathArray;
+            }
             $result = $this->_multipleRecordsToJson($records);
         } else {
             $filter = $this->_decodeFilter($filter, 'Tinebase_Model_Tree_Node_Filter');
             // ATTENTION sadly the pathfilter to Array does path magic, returns the flatpath and not the statpath
             // etc. this is Filemanager path magic. We don't want that here!
             $filterArray = $filter->toArray();
-            array_walk($filterArray, function (&$val) use ($path) {
-                if ('path' === $val['field']) {
-                    $val['value'] = $path;
-                }
-            });
+            if (null !== $pathArray) {
+                $filterArray[] = $pathArray;
+        }
             $filter = new Tinebase_Model_Tree_Node_Filter($filterArray, '', array('ignoreAcl' => true));
 
             $pathFilters = $filter->getFilter('path', true);
