@@ -561,6 +561,8 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      * @param Tinebase_Record_RecordSet $definitions
      * @param Tinebase_Model_Application $application
      * @return array
+     *
+     * @todo move code to converter \Tinebase_Convert_ImportExportDefinition_Json
      */
     protected function _getImportDefinitionRegistryData(Tinebase_Record_RecordSet $definitions = null, Tinebase_Model_Application $application = null)
     {
@@ -590,22 +592,22 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
             Tinebase_Exception::log($e);
             $definitionsArray = array();
         }
-        
-        //Save space in Registry
+
+        // Save space in Registry -
+        // should not be done in \Tinebase_Convert_ImportExportDefinition_Json::_convertOptions
+        // because we want to see / edit the plugin options in the admin area
         unset($defaultDefinitionArray['plugin_options']);
         foreach ($definitionsArray as &$definition) {
             unset($definition['plugin_options']);
         }
 
-        $definitionData = array(
+        return [
             'defaultImportDefinition'   => $defaultDefinitionArray,
             'importDefinitions'         => array(
                 'results'    => $definitionsArray,
                 'totalcount' => count($definitionsArray),
             ),
-        );
-
-        return $definitionData;
+        ];
     }
 
     /**
