@@ -234,6 +234,19 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
         return $emails;
     }
 
+    /**
+     * @return string
+     * @throws Tinebase_Exception_InvalidArgument
+     */
+    public function getTitle()
+    {
+        try {
+            return $this->getName();
+        } catch (Exception $e) {
+            return parent::getTitle();
+        }
+    }
+
     /**
      * get name of attender
      * 
