@@ -67,6 +67,8 @@
  */
 class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
 {
+    const MODEL_PART_NAME = 'Contact';
+
     /**
      * const to describe contact of current account id independent
      * 
@@ -110,10 +112,10 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
      * @var array
      */
     protected static $_modelConfiguration = [
-        self::VERSION       => 25,
+        self::VERSION       => 26,
         'containerName'     => 'Addressbook',
         'containersName'    => 'Addressbooks', // ngettext('Addressbook', 'Addressbooks', n)
-        'recordName'        => 'Contact',
+        'recordName'        => self::MODEL_PART_NAME,
         'recordsName'       => 'Contacts', // ngettext('Contact', 'Contacts', n)
         'hasRelations'      => true,
         'copyRelations'     => false,
@@ -131,7 +133,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
 
         'titleProperty'     => 'n_fn',
         'appName'           => 'Addressbook',
-        'modelName'         => 'Contact',
+        'modelName'         => self::MODEL_PART_NAME,
         self::TABLE         => [
             self::NAME          => 'addressbook',
             self::INDEXES       => [
@@ -249,7 +251,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'email_query'       => [
                 'filter'            => Tinebase_Model_Filter_Query::class,
-                'title'             => 'Email', // _('Email') // TODO is this right?
+                'title'             => 'Email', // _('Email')
                 'options'           => [
                     'fields'            => [
                         'email',
@@ -258,6 +260,20 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
                 ],
                 'jsConfig'          => ['filtertype' => 'addressbook.contactemail'] // TODO later with FE fix it
             ],
+            'name_email_query'       => [
+                'filter'            => Tinebase_Model_Filter_Query::class,
+                'title'             => 'Name/Email', // _('Name/Email')
+                'options'           => [
+                    'fields'            => [
+                        'n_family',
+                        'n_given',
+                        'n_middle',
+                        'org_name',
+                        'email',
+                        'email_home',
+                    ]
+                ],
+            ],
         ],
 
         self::FIELDS        => [
@@ -271,7 +287,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'adr_one_countryname'           => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Country', // _('Country')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -279,7 +295,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'adr_one_locality'              => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'City', // _('City')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -287,28 +303,28 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'adr_one_postalcode'            => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Postalcode', // _('Postalcode')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'adr_one_region'                => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Region', // _('Region')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'adr_one_street'                => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Street', // _('Street')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'adr_one_street2'               => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Street 2', // _('Street 2')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -329,7 +345,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'adr_two_countryname'           => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Country (private)', // _('Country (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -337,35 +353,35 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'adr_two_locality'              => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'City (private)', // _('City (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'adr_two_postalcode'            => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Postalcode (private)', // _('Postalcode (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'adr_two_region'                => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Region (private)', // _('Region (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'adr_two_street'                => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Street (private)', // _('Street (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'adr_two_street2'               => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Street 2 (private)', // _('Street 2 (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -386,7 +402,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'assistent'                     => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Assistent', // _('Assistent')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -444,7 +460,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'industry'                      => [
                 self::TYPE                      => self::TYPE_STRING, // TODO make a record out of it?
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Industry', // _('Industry')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -462,7 +478,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
                     Zend_Filter_Input::ALLOW_EMPTY      => true,
                 ],
                 self::OMIT_MOD_LOG              => true,
-                self::SYSTEM                    => true
+                self::SYSTEM                    => true,
             ],
             'note'                          => [
                 self::TYPE                      => self::TYPE_FULLTEXT,
@@ -496,7 +512,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'n_given'                       => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'First Name', // _('First Name')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -504,28 +520,28 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'n_middle'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Middle Name', // _('Middle Name')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'n_prefix'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Title', // _('Title')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'n_suffix'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Suffix', // _('Suffix')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'n_short'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Short Name', // _('Short Name')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -540,7 +556,7 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'org_unit'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Unit', // _('Unit')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -551,9 +567,11 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
                 self::IS_VIRTUAL                => true,
                 'noResolve'                     => true,
                 'config'                        => [
-                    'recordClassName'               => Tinebase_Model_Path::class,
-                    'controllerClassName'           => Tinebase_Record_Path::class,
-                    'filterClassName'               => Tinebase_Model_PathFilter::class,
+                    'appName' => 'Tinebase',
+                    'modelName' => 'Path',
+                    'recordClassName' => Tinebase_Model_Path::class,
+                    'controllerClassName' => Tinebase_Record_Path::class,
+                    'filterClassName' => Tinebase_Model_PathFilter::class,
                 ],
                 'label'                         => 'Paths', // _('Paths')
                 'validators'                    => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -577,14 +595,14 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'role'                          => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Job Role', // _('Job Role')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'room'                          => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Room', // _('Room')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -607,161 +625,161 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             ],
             'tel_assistent'                 => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::SYSTEM                    => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_car'                       => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Car phone', // _('Car phone')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_cell'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Mobile', // _('Mobile')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_cell_private'              => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Mobile (private)', // _('Mobile (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_fax'                       => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Fax', // _('Fax')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_fax_home'                  => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Fax (private)', // _('Fax (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_home'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Phone (private)', // _('Phone (private)')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_pager'                     => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Pager', // _('Pager')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_work'                      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Phone', // _('Phone')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'tel_other'                     => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_prefer'                    => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_assistent_normalized'      => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_car_normalized'            => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_cell_normalized'           => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_cell_private_normalized'   => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_fax_normalized'            => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_fax_home_normalized'       => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_home_normalized'           => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_pager_normalized'          => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_work_normalized'           => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_other_normalized'          => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'tel_prefer_normalized'         => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 40,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 'system'                        => true
             ],
             'title'                         => [
                 self::TYPE                      => self::TYPE_STRING,
-                self::LENGTH                    => 64,
+                self::LENGTH                    => 86,
                 self::NULLABLE                  => true,
                 self::LABEL                     => 'Job Title', // _('Job Title')
                 self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -954,11 +972,11 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             'n_family' => 255,
             'n_fileas' => 255,
             'org_name' => 255,
-            'n_given' => 64,
-            'n_middle' => 64,
-            'n_prefix' => 64,
-            'n_suffix' => 64,
-            'n_short' => 64,
+            'n_given' => 86,
+            'n_middle' => 86,
+            'n_prefix' => 86,
+            'n_suffix' => 86,
+            'n_short' => 86,
          ] as $field => $allowedLength) {
             if (isset($_data[$field]) && mb_strlen($_data[$field]) > $allowedLength) {
                 if (Tinebase_Core::isLogLevel(Zend_Log::WARN))
@@ -1029,6 +1047,15 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
         return null;
     }
 
+    public function getMsisdn()
+    {
+        foreach (['tel_cell_normalized', 'tel_cell_private_normalized','tel_car_normalized'] as $property) {
+            if (strlen($this->{$property}) > 0) {
+                return substr(ltrim(ltrim($this->{$property}, '0'), '+'), 0, 15);
+            }
+        }
+    }
+
     /**
      * fills a contact from json data
      *
@@ -1205,4 +1232,11 @@ class Addressbook_Model_Contact extends Tinebase_Record_NewAbstract
             'account_id'  => true,
         ]);
     }
+
+    public function unsetFieldsBeforeConvertingToJson()
+    {
+        parent::unsetFieldsBeforeConvertingToJson();
+
+        unset($this->jpegphoto);
+    }
 }
