@@ -9,6 +9,8 @@
  * @copyright   Copyright (c) 2010-2019 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
+use Tinebase_ModelConfiguration_Const as TMCC;
+
 /**
  * class to hold data representing one node in the tree
  *
@@ -96,6 +98,7 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
         'createModule'      => false,
         'exposeHttpApi'     => false,
         'exposeJsonApi'     => false,
+        TMCC::HAS_SYSTEM_CUSTOM_FIELDS => true,
 
         'titleProperty'     => 'name',
         'appName'           => 'Tinebase',
@@ -428,4 +431,16 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
         }
         return 0;
     }
+
+    public function getPreviousRevision()
+    {
+        // sort resets keys! so we can use it
+        if (is_array($ar = $this->available_revisions) && !empty($ar)) {
+            sort($ar, SORT_NUMERIC);
+            if (false !== ($idx = array_search($this->revision, $ar)) && $idx > 0) {
+                return $ar[$idx - 1];
+            }
+        }
+        return 0;
+    }
 }
