@@ -305,7 +305,10 @@ class Tinebase_Notes implements Tinebase_Backend_Sql_Interface
         $notesOfRecords->addIndices(array('record_id'));
         
         // add notes to records
-        Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Getting ' . count($notesOfRecords) . ' notes for ' . count($_records) . ' records.');
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG) && count($notesOfRecords) > 0) {
+            Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' Getting ' . count($notesOfRecords)
+                . ' notes for ' . count($_records) . ' records.');
+        }
         foreach($_records as $record) {
             //$record->notes = Tinebase_Notes::getInstance()->getNotesOfRecord($modelName, $record->getId(), $_backend);
             $record->{$_notesProperty} = $notesOfRecords->filter('record_id', $record->getId());
@@ -522,7 +525,9 @@ class Tinebase_Notes implements Tinebase_Backend_Sql_Interface
                         if ($oldData) {
                             try {
                                 $oldDataString = $controller->get($oldData, null, false, true)->getTitle();
-                            } catch(Tinebase_Exception_NotFound $e) {
+                            } catch (Tinebase_Exception_NotFound $tenf) {
+                                $oldDataString = $oldData;
+                            } catch (Tinebase_Exception_AccessDenied $tead) {
                                 $oldDataString = $oldData;
                             }
                         } else {
@@ -883,7 +888,7 @@ class Tinebase_Notes implements Tinebase_Backend_Sql_Interface
      */
     public function update(Tinebase_Record_Interface $_record)
     {
-        $data = $_record->toArray(false);
+        $data = $_record->toArray(false, false);
 
         if (!isset($data['id'])) throw new Tinebase_Exception_Backend('id not set');
         if (mb_strlen($data['note']) > 65535) {
