@@ -161,6 +161,33 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
         }
     }
 
+    protected function _checkName($name)
+    {
+        if (strpos($name, '/') !== false) {
+            $translate = Tinebase_Translation::getTranslation('Tinebase');
+            throw new Tinebase_Exception_SystemGeneric($translate->_('node name must not contain the character /'));
+        }
+    }
+
+    protected function _checkRecordName(Tinebase_Model_Tree_Node $node)
+    {
+        $this->_checkName($node->name);
+    }
+
+    /**
+     * Creates new entry
+     *
+     * @param   Tinebase_Record_Interface $_record
+     * @return Tinebase_Record_Interface
+     * @throws Exception
+     * @todo    remove autoincremental ids later
+     */
+    public function create(Tinebase_Record_Interface $_record)
+    {
+        $this->_checkRecordName($_record);
+        return parent::create($_record);
+    }
+
     /**
      * Updates existing entry
      *
@@ -171,6 +198,8 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
      */
     public function update(Tinebase_Record_Interface $_record, $_doModLog = true)
     {
+        $this->_checkRecordName($_record);
+
         $oldRecord = $this->get($_record->getId(), true);
         $newRecord = parent::update($_record);
 
@@ -225,6 +254,10 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
             $oldRecords = $this->getMultiple($_ids);
         }
 
+        if (isset($_data['name'])) {
+            $this->_checkName($_data['name']);
+        }
+
         $result = parent::updateMultiple($_ids, $_data);
 
         if (null !== $oldRecords) {
@@ -264,7 +297,7 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
      */
     protected function _inspectForPreviewCreation(Tinebase_Model_Tree_Node $_newRecord, Tinebase_Model_Tree_Node $_oldRecord = null)
     {
-        if (true !== Tinebase_Config::getInstance()->{Tinebase_Config::FILESYSTEM}->{Tinebase_Config::FILESYSTEM_CREATE_PREVIEWS}
+        if (! Tinebase_FileSystem::getInstance()->isPreviewActive()
                 || ($_oldRecord !== null && $_oldRecord->hash === $_newRecord->hash) || (int)$_newRecord->revision < 1 ||
                 empty($_newRecord->hash) || Tinebase_Model_Tree_FileObject::TYPE_FILE !== $_newRecord->type) {
             return;
