@@ -205,6 +205,7 @@ class Tinebase_User implements Tinebase_Controller_Interface
         self::$_instance = null;
         self::$_backendConfiguration = null;
         self::$_backendType = null;
+        Tinebase_EmailUser::destroyInstance();
     }
 
     /**
@@ -467,7 +468,6 @@ class Tinebase_User implements Tinebase_Controller_Interface
      * @return Tinebase_Model_FullUser|null
      * @throws Tinebase_Exception
      * 
-     * @todo make use of dbmail plugin configurable (should be false by default)
      * @todo switch to new primary group if it could not be found
      */
     public static function syncUser($username, $options = array())
@@ -491,22 +491,24 @@ class Tinebase_User implements Tinebase_Controller_Interface
                 $userBackend->registerLdapPlugin($plugin);
             }
         }
-        
-        $user = $userBackend->getUserByPropertyFromSyncBackend('accountLoginName', $username, 'Tinebase_Model_FullUser');
+
+        try {
+            $user = $userBackend->getUserByPropertyFromSyncBackend('accountLoginName', $username, 'Tinebase_Model_FullUser');
+        } catch (Tinebase_Exception_NotFound $tenf) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' '
+                . $tenf->getMessage());
+            return null;
+        }
+
         $user->accountPrimaryGroup = Tinebase_Group::getInstance()->resolveGIdNumberToUUId($user->accountPrimaryGroup);
         
         $userProperties = method_exists($userBackend, 'getLastUserProperties') ? $userBackend->getLastUserProperties() : array();
 
-
         $hookResult = self::_syncUserHook($user, $userProperties);
         if (! $hookResult) {
             return null;
         }
 
-
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ . ' ' 
-            . print_r($user->toArray(), TRUE));
-
         $oldContainerAcl = Addressbook_Controller_Contact::getInstance()->doContainerACLChecks(false);
         $oldRequestContext = Addressbook_Controller_Contact::getInstance()->getRequestContext();
 
@@ -793,6 +795,9 @@ class Tinebase_User implements Tinebase_Controller_Interface
             if (!isset($options['syncContactData'])) {
                 $options['syncContactData'] = $syncOptions->{Tinebase_Config::SYNC_USER_CONTACT_DATA};
             }
+            if (!isset($options['syncAccountStatus'])) {
+                $options['syncAccountStatus'] = $syncOptions->{Tinebase_Config::SYNC_USER_ACCOUNT_STATUS};
+            }
         }
 
         if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
