@@ -49,9 +49,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Import CSV formated contacts from Outlook 2007 German address book"
 : "Importiere CSV formatierte Kontakte aus einem Outlook 2007 Deutsch Adressbuch"
 
+, "Import CSV formated contacts from Outlook 2010 German address book"
+: "Importiere CSV formatierte Kontakte aus einem Outlook 2010 Deutsch Adressbuch"
+
 , "CSV Outlook 2007 German"
 : "CSV Outlook 2007 Deutsch"
 
+, "CSV Outlook 2010 German"
+: "CSV Outlook 2010 Deutsch"
+
 , "It is not allowed to delete a contact linked to an user account!"
 : "Es ist nicht erlaubt, einen Kontakt zu Löschen, der zu einem Benutzerkonto gehört"
 
