@@ -907,6 +907,192 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Only system accounts can be added to Addressbook group"
 : "Nur Systembenutzer in der zugehörigen Addressbuch-Gruppe erlauben"
 
+, "Disabled"
+: "Deaktiviert"
+
+, "Enabled"
+: "Aktivirt"
+
+, "Unknown status ({0})"
+: "Unbekannter Status ({0})"
+
+, "E-mail"
+: "E-Mail"
+
+, "E-mail Alias"
+: "E-Mail Alias"
+
+, "This alias can be used for sending e-mails."
+: "Dieser Alias kann zum Versenden von E-Mails verwendet werden."
+
+, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
+: "Sie dürfen keine E-Mail-Adresse zur Weiterleitung festlegen, die mit der primären E-Mail-Adresse des Benutzers oder einem seiner Aliase identisch ist."
+
+, "E-mail Forward"
+: "E-Mail weiterleiten"
+
+, "Add a forwarding address..."
+: "Eine Weiterleitungs-Adresse hinzufügen..."
+
+, "E-mail usage"
+: "E-Mail-Nutzung"
+
+, "Container Hierarchy/Name"
+: "Kalender Hierarchie/Name"
+
+, "Info"
+: "Info"
+
+, "E-mail Accounts"
+: "E-Mail Konten"
+
+, "Feature is disabled by configuration."
+: "Funktion ist durch die Konfiguration deaktiviert."
+
+, "Enabled Features"
+: "Aktiviertes Features"
+
+, "Enabled Features in Admin Application."
+: "Aktiviertes Features in der Admin Anwendung."
+
+, "Prevent special chars in login name"
+: "Vermeiden Sie Sonderzeichen im Anmeldenamen"
+
+, "Force retype of new password in user edit dialog"
+: "Erzwinge die erneute Eingabe des neuen Passworts im Benutzer-Bearbeitungsdialog"
+
+, "Manage access log"
+: "Zugriffsprotokoll bearbeiten"
+
+, "Delete access log entries."
+: "Zugriffsprotokoll-Einträge löschen."
+
+, "Manage accounts"
+: "Benutzerkonten verwalten"
+
+, "Add and edit users and groups, add group members, change user passwords."
+: "Benutzer und Gruppen anlegen und bearbeiten, Benutzer zu Gruppen zuordnen, Passwörter zurücksetzen."
+
+, "Manage e-mail accounts"
+: "E-Mail Konten verwalten"
+
+, "Add and edit shared and personal e-mail accounts."
+: "Persönliche und gemeinsame E-Mail Konten ansehen."
+
+, "Manage applications"
+: "Anwendungen verwalten"
+
+, "Enable and disable applications, edit application settings."
+: "Anwendungen bearbeiten, aktivieren und deaktivieren."
+
+, "Manage roles"
+: "Rollen verwalten"
+
+, "Add and edit roles, add new members to roles, add application rights to roles."
+: "Rollen anlegen und bearbeiten, Benutzerkonten Rollen zuordnen, Rollen Anwendungs-Rechte zuweisen."
+
+, "Manage shared tags"
+: "Gemeinsame Tags verwalten"
+
+, "Add, delete and edit shared tags."
+: "Gemeinsame Tags anlegen, bearbeiten und löschen."
+
+, "Manage computers"
+: "Computer verwalten"
+
+, "Add, delete and edit (samba) computers."
+: "(Samba-) Computer hinzufügen, löschen und bearbeiten."
+
+, "Manage containers"
+: "Container verwalten"
+
+, "Add, delete and edit containers and manage container grants."
+: "Container anlegen, löschen und ändern, sowie die Container-Rechte setzen."
+
+, "Manage customfields"
+: "Zusatzfelder verwalten"
+
+, "Add and edit customfields."
+: "Zusatzfelder anlegen und editieren."
+
+, "View access log"
+: "Zugriffsprotokoll ansehen"
+
+, "View access log list."
+: "Zugriffsprotokoll-Liste ansehen."
+
+, "View accounts"
+: "Benutzerkonten ansehen"
+
+, "View accounts list and details."
+: "Benutzerkonten ansehen (Liste und Details)"
+
+, "View e-mail accounts"
+: "E-Mail Konten ansehen"
+
+, "View shared and personal e-mail accounts."
+: "Persönliche und gemeinsame E-Mail Konten ansehen."
+
+, "View applications"
+: "Anwendungen ansehen"
+
+, "View applications list and details."
+: "Anwendungen ansehen (Liste und Details)"
+
+, "View roles"
+: "Rollen ansehen"
+
+, "View roles list and details."
+: "Rollen ansehen (Liste und Details)"
+
+, "View shared tags"
+: "Gemeinsame Tags ansehen"
+
+, "View shared tags list and details."
+: "Gemeinsame Tags ansehen (Liste und Details)"
+
+, "View computers"
+: "Computer ansehen"
+
+, "View computers list and details."
+: "Computerliste und -details ansehen."
+
+, "View containers"
+: "Container ansehen"
+
+, "View personal and shared containers."
+: "Persönlichen und gemeinsame Container ansehen."
+
+, "View customfields"
+: "Zusatzfelder ansehen"
+
+, "View customfields list."
+: "Liste der Zusatzfelder ansehen."
+
+, "View serverinfo"
+: "Serverinformationen ansehen"
+
+, "View serverinfo list."
+: "Listen der Serverinformationen ansehen."
+
+, "View quota usage"
+: "Quota Nutzung ansehen"
+
+, "View quota usage."
+: "Quota Nutzung ansehen."
+
+, "You are not allowed to set a forward e-mail address that is identical to the users primary e-mail or one of his aliases."
+: "Sie dürfen keine E-Mail-Adresse zur Weiterleitung festlegen, die mit der primären E-Mail-Adresse des Benutzers oder einem seiner Aliase identisch ist."
+
+, "E-Mail"
+: "E-Mail"
+
+, "E-Mail Accounts"
+: "E-Mail Konten"
+
+, "Account only"
+: "Nur Systembenutzer"
+
 , "Application"
 : "Anwendung"
 
