@@ -125,7 +125,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 : "Sollen links in E-Mail Text gefiltert werden. Nur interne Verweise sind erlaubt wenn dies eingeschaltet wird"
 
 , "System Account Folder Defaults"
-: "Standard Ordner für System Nutzer"
+: "Standardordner für System Nutzer"
 
 , "Paths of the special folders (like Sent, Trash, ...)"
 : "Pfad für spezielle Ordner (wie Gesendet, Mülleimer, …)"
@@ -439,12 +439,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notifications"
 : "Benachrichtigungen"
 
-, "Auto-move notifications"
-: "Automatisches Verschieben von Benachrichtigungen"
-
-, "Auto-move notifications folder"
-: "Ordner für Benachrichtigungen"
-
 , "Mark Folder as read"
 : "Ordner als gelesen markieren"
 
@@ -1187,7 +1181,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 : "Tine20"
 
 , "Filed as:"
-: "Abgelebt unter:"
+: "Abgelegt unter:"
 
 , "Select Message File Location"
 : "Ablageort für Nachricht auswählen"
@@ -1231,6 +1225,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "All inboxes"
 : "Alle Posteingänge"
 
+, "Default Font"
+: "Standardschriftart"
+
+, "Setting the default font in the E-Mail app"
+: "Einstellung für die Standardschriftart im der E-Mail-Modul"
+
 , "Default Email Account"
 : "Standard E-Mailkonto"
 
@@ -1288,10 +1288,38 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Save as Record Attachment"
 : "Als Datensatz Anhang speichern"
 
+, "Folder with this name already exists!"
+: "Ordner mit dem Namen ist bereits vorhanden!"
 
+, "Failure on create folder"
+: "Fehler beim anlegen des Ordners"
 
+, "Convert this account to a shared account. Please set a new password for the account:"
+: "Dieses Konto in einen gemeinsamen Account umwandeln. Bitte setzen Sie ein neues Passwort:"
 
+, "New Password"
+: "Neues Passwort"
 
+, "Converting Account ..."
+: "Konto wird umgewandelt ..."
+
+, "Convert Account"
+: "Konto umwandeln"
+
+, "This alias can be used for sending e-mails."
+: "Dieser Alias kann zum versenden von E-Mails genutzt werden."
+
+, "Auto-move notifications"
+: "Automatisches Verschieben von Benachrichtigungen"
+
+, "Auto-move notifications folder"
+: "Ordner für Benachrichtigungen"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: "Es ist nicht erlaubt, E-Mails an sich selbst weiterzuleiten. Bitte ändern Sie den Empfänger."
+
+, "Redirects to external email domains are not allowed."
+: "Weiterleitungen zu externen E-Mail-Konten sind nicht erlaubt."
 
 , "Signature"
 : "Signatur"
